(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 9.0' *)

(*************************************************************************)
(*                                                                       *)
(*                                                                       *)
(*  This file was created under the Wolfram Enterprise licensing terms.  *)
(*                                                                       *)
(*       For additional information concerning CDF licensing see:        *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*                                                                       *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1063,         20]
NotebookDataLength[    193415,       4374]
NotebookOptionsPosition[    182813,       4122]
NotebookOutlinePosition[    193698,       4366]
CellTagsIndexPosition[    193655,       4363]
WindowTitle->Liquidity Trap
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Liquidity Trap", "Title"],

Cell["\<\
In Keynesian economics, a liquidity trap is a condition in which cash \
injected by a central bank into a private banking system does not lower \
interest rates and consequently fails to spur economic growth. Liquidity \
traps are triggered when people hold onto cash in anticipation of negative \
events like inadequate aggregate demand, deflation, and war. Liquidity traps \
are identifiable by two key features: near-zero short-term interest rates and \
monetary base variability without variability in general price levels.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Supporting Data for Liquidity Trap Analysis", "Section"],

Cell["\<\
Though the long-term effects of the monetary policy are debatable, evidence \
suggests real activity is significantly affected by monetary policy. In other \
words, when interest rates increase, GDP decreases. The theory is that lower \
interest rates motivate investment in the local economy during recessions, \
increasing production and employment.\
\>", "Text"],

Cell["\<\
As a result, an interest rate of zero prevents the central bank from \
stimulating the economy by lowering the interest rate. Liquidity traps \
constrain the monetary authority because they are associated with recessions, \
but debates about how to implement efficient monetary policy during a \
liquidity trap are getting more attention.\
\>", "Text"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RotationBox[
      StyleBox["\<\"YIELD\"\>",
       StripOnInput->False,
       LineColor->GrayLevel[0.5],
       FrontFaceColor->GrayLevel[0.5],
       GraphicsColor->GrayLevel[0.5],
       FontFamily->"Arial",
       FontSize->15,
       FontWeight->Bold,
       FontColor->GrayLevel[0.5],
       $CellContext`BackFaceColor -> GrayLevel[0.5]],
      BoxRotation->1.5707963267948966`], 
     GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJxVlV1Ik1EYx1cXaUvTyj4mfiwKmhfFyGh1Ie1kTIMuLFCyhCxm0Af5xqKL
ghwzu+imKUbURUyyDyrsDbqoFF0WdFGuSRfdNNja+zlXrMgsV5Dnv+fAdkDk
x3PO83+e/3nOu/XHug90LbZYLOcX/vj/hRXUI0mWuFAx0nR0g3uBQ1osyRqs
n+5IDRs5x8u+JtnFhXDiAuL2nX+TDGFrLWfL8mUKm3rPF7i8tFJhB57X9M3s
r+Lcsr1OYcMSzwgOHtmhsGYIgqVtTQrprePsr28T59dyDnd0KQz4vAJ6V84J
Xo36DvUq7NrkrKPj2hrOmfYBhb3mOAl29g4pjO+u6UN+6bEs9JDf/2hC1AcO
PowoLM23z1Ryjn6MKew4VjX6+5dWcv1ftUNvOkv971uP+qatKunBD/e8TaX6
aqC3oa6AO3+7VAZ7K7BfmvOo5Dfisr1NZQiPwK/M3i41d18J9BOtOaeyWzf5
Qr/x6l6V/APbmwZU9ovbMbsKetKQSv0sh163rLLcKID9ZyaE3lL4fyMi9Jag
v1cxsb8YetfTIj/imcGs0EfcOW7VWB0PO8CSbtMYxudTEeZjzKGxs7iQUtQ3
6tLo/ArMo+LRaL5Qf7y0TZxHf+EvXi2//2jCp1H9mI/yZb0aq8WFgFu2DWhU
P+aps36oIL+0VRb5EJcPT2j5/mUuR0Q+xKPtMY3mBxw/mNZYPRbYHshq5F/O
/0dWnfxA3O236fn6LT0OnfoDBx+4dOqnDHrTHp3heAf8ke+1inzg8F2vTvor
cV8ffDr5i3zu3wGd3l/Oj7l+neqHf52/QkIf7yFUK4vzmLd484Se70+4OqKT
P5ifaFVMp3kugf+etNBbBL3urE7zN7+Lz8ceq0HvJcvZ3WgzyC/E/acdBp3/
wzl83WXQ+//BOXTSY5AeWD7RapCfac6ZAa9B9X+F3pjPIL8Qd48GxPlvnFte
9gu9Wc7BZEjs/8s5WiIb5Ndi+J8YN+h7gvkPx6cM+v7g/VisMYPuD/Ptrk8b
5Fc55qM4a5AfuC9nkdUsmEenzaTzYLndYdL3KTcfW1wmfS/Aoc0ek+rPvZe2
VpPmAfNj93tNmn/U6+zxmdTPT/hxKWCSHzn/7/eb5J8K/6MhsT8M/+8+Efpv
4P/wuEm/D2/h/9SUqPcp/J/7bNL9jXAufz9TcN7+br6AO38uTRXoVdtS1M9r
1PdjUyo/X/D79hSdH8Z9VXoED0JvT6vYfxt6jV4Rf4b6dvtSNN8vOEunAgUs
D/an8vvB72defsQF/wcDhdP9
        "], {{{}, 
          {RGBColor[
           0.6333333333333333, 0.7533333333333335, 0.9333333333333333], 
           EdgeForm[None], 
           GraphicsGroupBox[{
             PolygonBox[{{111, 118, 116, 115, 114, 113, 112}}], 
             PolygonBox[{{1, 117, 111, 110, 109, 108, 107, 106, 105, 104, 103,
               102, 101, 100, 99, 98, 97, 96, 95, 94, 93, 92, 91, 90, 89, 88, 
              87, 86, 85, 84, 83, 82, 81, 80, 79, 78, 77, 76, 75, 74, 73, 72, 
              71, 70, 69, 68, 67, 66, 65, 64, 63, 62, 61, 60, 59, 58, 57, 56, 
              55, 54, 53, 52, 51, 50, 49, 48, 47, 46, 45, 44, 43, 42, 41, 40, 
              39, 38, 37, 36, 35, 34, 33, 32, 31, 30, 29, 28, 27, 26, 25, 24, 
              23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7,
               6, 5, 4, 3, 2}}]}]}, {}, {}}, {{}, {}, 
          {Hue[0.6, 0.5, 0.9], Thickness[Large], 
           LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17,
             18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
            34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 
            50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 
            66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 
            82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 
            98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 
            111, 112, 113, 114, 115, 116}]}}}], {}},
      AspectRatio->NCache[
        Rational[1, 4], 0.25],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{2.6586144*^9, 0.02},
      AxesStyle->Dashing[{Small, Small}],
      BaseStyle->(FontFamily -> "Arial"),
      FrameTicks->None,
      GridLines->{{}, None},
      ImageSize->500,
      Method->{},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic},
      Ticks->None]},
    {
     RotationBox[
      StyleBox["\<\"GDP\"\>",
       StripOnInput->False,
       LineColor->GrayLevel[0.5],
       FrontFaceColor->GrayLevel[0.5],
       GraphicsColor->GrayLevel[0.5],
       FontFamily->"Arial",
       FontSize->15,
       FontWeight->Bold,
       FontColor->GrayLevel[0.5],
       $CellContext`BackFaceColor -> GrayLevel[0.5]],
      BoxRotation->1.5707963267948966`], 
     GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJxF1W1oE3ccB/DDvVDTOgui7Mq6Zeg07aYLpmvmCyGZEjcpGMYazda5MpJC
ddiwWOYE9UjGHmCypCiiLyQFrcUHelqf1nbNqdM508Qr4ovBgqdNLk2WabRq
q9Ftue/vN3bQhw+/x///UvraZ50f+GcIgtBV+TJ+Vp5ILjXuxG8b+x2V7zE9
Pe5Mjlaeu7A2969x54H9lccmGzaveMb5u2HhxaoM8ptTcM2c2gzlN5w07G6q
J4t+OPLpO5x/CA40rsk4bcaTgCWbh+urThlWWv0ZZ7vxrISFb7ZyvgRrH4U5
fhMuebsz2E9aNGDYGu6h/IGDcOC4zP3vwNKxOMfXn8Z+R1NcPwCrN9IcX3QG
53te5P33waWxMs9/BgtjpizVrztr2PFUzFI8DEsL67N0vzPOGW6btmdpHw8c
mHJx/W5YNnsov/lbuPS+n+t7YfWVrVz/D6zVhXne2vN4X2u6/6uH2wI9XF+E
A50yx1t/wn5b4jx/EFb2pdj1gzjfhXSW7r8V1vYWef4JuLSnzPFp2Dpi0mne
tiHMy4k6xTXYPWzhuH8Y+w3ZOX4ejmVcOvVv/Bnz5ngov/krWLnj03Fe/TSs
3g7qtG/tCN5XVZj9Jexu7KZ+4k24zdbD8R1x7LdcJgu3YPnjOMffUnC+r1Mc
74BVb5r2nRyAtQ1F6v/7E9gcKtN+ixsuYN4xU47irbBDEsneKOzeZcmhvyMN
R/rsObqfpouYN+bKUb8uWO5toXzlOKwc9nG/MixcD3J++yXMmw5Rv+oDsHsq
yvvM/wX7PY5Rvr4Sjr0qk3u7YO29OO/3HazUpXi/q7D6cprnXYNrXEXeJwe7
O8vcr+EyPh+rTRN0n5/AjlXiBM3/EZY+t0zQfjKs7LVTvP0eHNvkmqC/z7ev
4D46Wsi2s3Cp20f9HfN/xbzhIOdvhh1DIYorCdg9GOW45SrufzzG+3wPq9Uy
7SPO+g3zbo/wfuthRUvyvAQsmNJU37vwGubZityvDzbPKtO84CPYOtOUp/o3
Evg8WsU8nWc7LHstFJeScGSZnfPfHMV9LHVR/mQXrHlaKC6chM2Sj+LBPti6
K5jH+/uhBDt2hvL0/v6GpSPRPL2/DlhRY+T9C2je4X6qr34Blg+N8L4vwaVk
kuNf0LypP3hfml8z+if3m5vEfomnNF/3wW0PZxfofuNwrE4s0P6XYenBEvLk
8hTu435Tgep3wGqti+q9WbhmdUuBPq8fXse8VT6qt0Vg67vBAt3XAziwOUTx
ebNVnG9PlHzj9f+N/Mr/z38BbrTM3w==
        "], {{{}, 
          {RGBColor[
           0.6333333333333333, 0.7533333333333335, 0.9333333333333333], 
           EdgeForm[None], 
           GraphicsGroupBox[
            PolygonBox[{{1, 117, 116, 115, 114, 113, 112, 111, 110, 109, 108, 
             107, 106, 105, 104, 103, 102, 101, 100, 99, 98, 97, 96, 95, 94, 
             93, 92, 91, 90, 89, 88, 87, 86, 85, 84, 83, 82, 81, 80, 79, 78, 
             77, 76, 75, 74, 73, 72, 71, 70, 69, 68, 67, 66, 65, 64, 63, 62, 
             61, 60, 59, 58, 57, 56, 55, 54, 53, 52, 51, 50, 49, 48, 47, 46, 
             45, 44, 43, 42, 41, 40, 39, 38, 37, 36, 35, 34, 33, 32, 31, 30, 
             29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 
             13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2}}]]}, {}, {}}, {{}, {}, 
          {Hue[0.6, 0.5, 0.9], Thickness[Large], 
           LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17,
             18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
            34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 
            50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 
            66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 
            82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 
            98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 
            111, 112, 113, 114, 115, 116}]}}}], {}},
      AspectRatio->NCache[
        Rational[1, 4], 0.25],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{2.6586144*^9, 4015.},
      AxesStyle->Dashing[{Small, Small}],
      BaseStyle->(FontFamily -> "Arial"),
      FrameTicks->None,
      GridLines->{{}, None},
      ImageSize->500,
      Method->{},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic},
      Ticks->None]},
    {
     RotationBox[
      StyleBox["\<\"MB\"\>",
       StripOnInput->False,
       LineColor->GrayLevel[0.5],
       FrontFaceColor->GrayLevel[0.5],
       GraphicsColor->GrayLevel[0.5],
       FontFamily->"Arial",
       FontSize->15,
       FontWeight->Bold,
       FontColor->GrayLevel[0.5],
       $CellContext`BackFaceColor -> GrayLevel[0.5]],
      BoxRotation->1.5707963267948966`], 
     GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJw9lQtsU1UYx3EhkywNaZAgFiSCImVKKERCxSh8qHNCgDpJRYKgY4yHMC5Q
5nhtsHXAGLhShPEQtpUNxkC4zA2Qx+yAAcKoNxPlsVBCdp9ljCKZBKjRc/+n
2qRpfjk3//O73/m+0/7pC9NmJXTp0mUp+5q/7CNsktqo+5Da3Q9Gzh7D2DEr
3EY1D1smpFeCfcUdbZR2ol/hvbtg18xYG/2eY7w+zDnHZLHIItPF8SOLqBws
fGWTqe5SdkPZqLkmS+uSZZp+8mNLQivYN8Mp05qt7xfPnznP5GhhqkzltqG3
X1PB4hdumaL7L4wfuflrk63eTJlGj2AJ9vnIr8mWqa1q1/lXpiyAb743vu4D
Rz/3y2SiJTELvqsDMn1QPF971ggW99XK9M6dSZtK0xciLzcoU8qxR39fuwGW
KiWZrlR8eOzRZwJ8V4ZlWtHz8Ed3c8DRQIdMC7RnBx7WgcXlsfj7toCtFRaF
+3RdhLwcm8Lr+wLYUZas8HrOBkeznQpd3yu8m3QG7NqdqtCW3l3d3QcvRt5S
t0J9WHkSD4KFXZkKVbPyFA1cgrwlHoX77QT7dngVmvI2M4qCXYv8CiWaBU/2
wLc0oNDVZvapBgsLRYUK731yot/gpfDdGlSokulcLwM7TksKbb6/cvSI3Gz4
bgkrNM6S8Ma6hG+Qf7Ijvv9qsNUfU3j9huYg/4RFpbFfKtKAf8AOn03lfp5l
8D2WrFJ/cfGczYOXI+9bp0qNl1lABVisS1WJ7dbr5lOwsNGtUkMZa5jhK+Bb
m6ny8zgL9m3wqDQ1g53w8yvhK3rjz7vA4nq/yv3Xgq1HAiqlW5nRebC0VlR5
fQetgu8PQZX3TxE46g2pvP9jYNfBsEqDhnU71Dc/F3kF7Srv9zawcCCm0qbS
rB4FaXnI/9Wi0TbW/tp9sG+/TaO8eac9W95ajbw8u0asWq1P5oLFKqdGL7F2
GNIMtjanaoTJjYKlvW6NOtjxTPesge/lTI3Mds45Do5WeOLPz8hH/iWvRtNK
znba6wqQV+7XaB8bJ/E3rAsXAhqfzwjYsUfU+Pn0wfO+80GNz+sQsOv7kEY9
CoKXK/xg8WxYI7O8vW6BhZ3tGj/Pei98gzGN2DTsv6CBfduTdN4fJYXwbbDp
9Ce7fqwRsLjNrvP9x6yF7xmnzvtnElj6LkXn/onr4HvKrdNk84J4Exz1Z+i0
nZU/WAJ2/eTR+Xl4weIdr87n9w5YOO7XiXXz8p5T1iP/dkDn81EG9tWLOpm6
revB0dagTq+2Psmd9xgs/hjS+fnbi+B7K6zzemWBpaPtcV8/2HEjptNAc0Cf
gqNHkgx+//beAN8/bAa/X18EWw/b4+vvgYVrToPfL1lgx6EUg8xxaNkI9rW4
DTrXaZ9Wcorn1WQYVGS+QR5YlDwGxdjjE/i6UJ1v0ERzIBKK4Rvyx/dvKkF+
Z8Ag1o21L4u74NssGmReT2vSwWJlg0HL2Hh027MDvldCBublaNZu5D8MGxRg
18Oqq3uQ90u7gft3srMcvg9iBt0MPf505pEy+F5MivD5l/C8eN8WIXMchl/B
utBkj/B+8uyF7z1nBPfd+HFVyDuXEqG/2OuPbayEr+GO8P6+CBYbMyJ4v+ea
wFbdEyFzu1A9WPo5P8Lvj1Fgh+qP0KG+UzNODaj6n//7//wXVW/7iw==
        "], {{{}, 
          {RGBColor[
           0.6333333333333333, 0.7533333333333335, 0.9333333333333333], 
           EdgeForm[None], 
           GraphicsGroupBox[
            PolygonBox[{{1, 117, 116, 115, 114, 113, 112, 111, 110, 109, 108, 
             107, 106, 105, 104, 103, 102, 101, 100, 99, 98, 97, 96, 95, 94, 
             93, 92, 91, 90, 89, 88, 87, 86, 85, 84, 83, 82, 81, 80, 79, 78, 
             77, 76, 75, 74, 73, 72, 71, 70, 69, 68, 67, 66, 65, 64, 63, 62, 
             61, 60, 59, 58, 57, 56, 55, 54, 53, 52, 51, 50, 49, 48, 47, 46, 
             45, 44, 43, 42, 41, 40, 39, 38, 37, 36, 35, 34, 33, 32, 31, 30, 
             29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 
             13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2}}]]}, {}, {}}, {{}, {}, 
          {Hue[0.6, 0.5, 0.9], Thickness[Large], 
           LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17,
             18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
            34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 
            50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 
            66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 
            82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 
            98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 
            111, 112, 113, 114, 115, 116}]}}}], {}},
      AspectRatio->NCache[
        Rational[1, 4], 0.25],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{2.6594784*^9, 185.748},
      AxesStyle->Dashing[{Small, Small}],
      BaseStyle->(FontFamily -> "Arial"),
      FrameTicks->None,
      GridLines->{{{2524521600, 
          GrayLevel[0.8]}, {2840140800, 
          GrayLevel[0.8]}, {3155673600, 
          GrayLevel[0.8]}, {3471292800, 
          GrayLevel[0.8]}, {3786825600, 
          GrayLevel[0.8]}}, None},
      ImageSize->500,
      Method->{},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic},
      Ticks->{{{2524521600, 
          FormBox["\"1980\"", TraditionalForm]}, {2840140800, 
          FormBox["\"1990\"", TraditionalForm]}, {3155673600, 
          FormBox["\"2000\"", TraditionalForm]}, {3471292800, 
          FormBox["\"2010\"", TraditionalForm]}, {3786825600, 
          FormBox["\"2020\"", TraditionalForm]}, {2587680000, 
          FormBox["\"\"", TraditionalForm]}, {2650752000, 
          FormBox["\"\"", TraditionalForm]}, {2713910400, 
          FormBox["\"\"", TraditionalForm]}, {2776982400, 
          FormBox["\"\"", TraditionalForm]}, {2903212800, 
          FormBox["\"\"", TraditionalForm]}, {2966371200, 
          FormBox["\"\"", TraditionalForm]}, {3029443200, 
          FormBox["\"\"", TraditionalForm]}, {3092601600, 
          FormBox["\"\"", TraditionalForm]}, {3218832000, 
          FormBox["\"\"", TraditionalForm]}, {3281904000, 
          FormBox["\"\"", TraditionalForm]}, {3345062400, 
          FormBox["\"\"", TraditionalForm]}, {3408134400, 
          FormBox["\"\"", TraditionalForm]}, {3534364800, 
          FormBox["\"\"", TraditionalForm]}}, None}]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> None, "Rows" -> None},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellGroupingRules->"InputGrouping"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Relationships Between Supporting Datasets", "Section"],

Cell["\<\
We can use a 3D visualization tool to see the relationships between two sets \
of variables that are crucial in spotting the liquidity trap. Below, we can \
see the changes between GDP, monetary base, and 3-month Treasury Bill.\
\>", "Text"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0.5], Thickness[0.005], 
    Line3DBox[{{4.015, 0.185748, 0}, {4.087400000000001, 0.189137, 0}, {
      4.147600000000001, 0.19106, 0}, {4.237, 0.193756, 0}, {
      4.302300000000001, 0.19700800000000002`, 0}, {
      4.3946000000000005`, 0.201832, 0}, {4.4531, 0.206844, 0}, {
      4.5163, 0.21110700000000002`, 0}, {4.5552, 0.21519200000000002`, 0}, {
      4.6196, 0.220538, 0}, {4.6693999999999996`, 0.225259, 0}, {
      4.7362, 0.234754, 0}, {4.8214, 0.236509, 0}, {
      4.9005, 0.24018899999999999`, 0}, {
      5.0226999999999995`, 0.24606200000000003`, 0}, {5.0906, 0.251081, 0}, {
      5.2077, 0.254776, 0}, {5.2995, 0.26149700000000003`, 0}, {
      5.4127, 0.26355500000000004`, 0}, {5.5273, 0.267309, 0}, {
      5.6284, 0.269164, 0}, {5.7115, 0.27226799999999995`, 0}, {
      5.7634, 0.273246, 0}, {5.8908000000000005`, 0.278495, 0}, {
      5.974600000000001, 0.283815, 0}, {6.0295000000000005`, 0.290566, 0}, {
      6.0233, 0.29868900000000004`, 0}, {6.0548, 0.306346, 0}, {
      6.1436, 0.31368, 0}, {6.2184, 0.319029, 0}, {6.2793, 0.322659, 0}, {
      6.380800000000001, 0.33055, 0}, {6.4923, 0.33857, 0}, {
      6.5865, 0.34599, 0}, {6.6975, 0.359888, 0}, {
      6.7482, 0.36815800000000004`, 0}, {6.8296, 0.37605500000000003`, 0}, {
      6.9042, 0.38699700000000004`, 0}, {7.0328, 0.399946, 0}, {
      7.1362, 0.407279, 0}, {7.2698, 0.418598, 0}, {7.3522, 0.426107, 0}, {
      7.4766, 0.431678, 0}, {7.5453, 0.435179, 0}, {7.6049, 0.444184, 0}, {
      7.7065, 0.448457, 0}, {7.7995, 0.45305399999999996`, 0}, {
      7.8931000000000004`, 0.45640800000000004`, 0}, {8.0615, 0.460294, 0}, {
      8.159, 0.466471, 0}, {8.287, 0.47262400000000004`, 0}, {
      8.402000000000001, 0.479762, 0}, {8.5519, 0.488132, 0}, {
      8.6917, 0.494188, 0}, {8.7883, 0.501157, 0}, {
      8.889700000000001, 0.510869, 0}, {8.994700000000002, 0.518572, 0}, {
      9.1465, 0.525247, 0}, {9.325600000000001, 0.537522, 0}, {
      9.450299999999999, 0.542, 0}, {9.5615, 0.5585460000000001, 0}, {
      9.7187, 0.5669339999999999, 0}, {9.9323, 0.587875, 0}, {
      10.036100000000001`, 0.63052, 0}, {10.283700000000001`, 0.602461, 0}, {
      10.3638, 0.605303, 0}, {10.475299999999999`, 0.611446, 0}, {
      10.512500000000001`, 0.613643, 0}, {10.6416, 0.6263289999999999, 0}, {
      10.6443, 0.635261, 0}, {10.7027, 0.662714, 0}, {
      10.837299999999999`, 0.668972, 0}, {10.938, 0.6898920000000001, 0}, {
      11.0398, 0.701258, 0}, {11.1057, 0.712071, 0}, {11.2308, 0.713933, 0}, {
      11.3714, 0.736836, 0}, {11.6284, 0.741596, 0}, {
      11.8185, 0.7539690000000001, 0}, {11.9914, 0.752564, 0}, {
      12.1835, 0.763953, 0}, {12.3694, 0.77901, 0}, {
      12.563799999999999`, 0.78789, 0}, {12.8162, 0.785107, 0}, {
      12.975700000000002`, 0.798927, 0}, {13.2065, 0.805001, 0}, {
      13.3833, 0.813768, 0}, {13.649799999999999`, 0.8183360000000001, 0}, {
      13.8029, 0.831283, 0}, {13.9105, 0.835048, 0}, {
      14.0684, 0.8349070000000001, 0}, {14.235, 0.839798, 0}, {
      14.4245, 0.8458669999999999, 0}, {14.5719, 0.849603, 0}, {
      14.69, 0.8554450000000001, 0}, {14.6729, 0.847977, 0}, {
      14.8171, 0.855413, 0}, {14.844299999999999`, 0.864278, 0}, {
      14.546700000000001`, 1.0166570000000001`, 0}, {
      14.381200000000002`, 1.772029, 0}, {14.3421, 1.752626, 0}, {
      14.3844, 1.639508, 0}, {14.5641, 1.883673, 0}, {14.6725, 1.971373, 0}, {
      14.8792, 2.076166, 0}, {15.0498, 2.027847, 0}, {
      15.231700000000002`, 1.972212, 0}, {15.2429, 2.034799, 0}, {
      15.4619, 2.490388, 0}, {15.611799999999999`, 2.725147, 0}, {
      15.818700000000002`, 2.6566300000000003`, 0}, {16.0416, 2.659712, 0}, {
      16.1604, 2.658503, 0}, {16.356, 2.650904, 0}, {16.4203, 2.589432, 0}, {
      16.5353, 2.705366, 0}}], Line3DBox[CompressedData["
1:eJxllnlQ1GUYx1Fk4xAWdn97cOzFLizXAtaIx0jvg6WCwBg4o6hgiiJ4YsAQ
A4qmoaKpCZqFRxlIQymSpQkhGUdUeENDlCKYqCQ4CngAHv0OZ9949p35/fOZ
d573+/s+x/vqElNjk0ZbWVllsJ81++2ufeQTL3YGl7kX210v2EBnNlM+Y7Ee
cstPJ26YR3mofWvx2lADDOyanWHYT3kOu70zWw+lB+q1FX2U89vtNVAT+4lu
13gXM79wnlsaKBlVbSPZS3nsGXXevRgPmDRtRtrgJcpL1nIne8DLkzl9Fc4S
Mw/nhXrAw4GZ87ZMlCCdSrBP8VyVlS1B8RUwpmH3uPePU87jMwzUTz2+vP0h
5jJorv6HUUVIzZz3a7ccjONsj3kUUV7H4Vo5iLNDvnlTwZg5F0WdpwSRhCG/
xDNIpwKiP3ScdaKFQf+rEPx8XWbmPVyYe27w+ZSAlqJSypfxSwWGymdbB9zl
I/3froWfJ+ln5myWj/Q/SgcbVlRnFP4pRzo10OTcWHXGUYH+Vw1p7o4dpo8t
+ePKv7Y/76KcLwdGAwW968h4tRLViRo4mX8rKOe3l3vAxvCf1qsmKkfWYacS
8q+2dzgUUl70GbfkoPqti5TcUKL8ymGe4ocrVmpXM3/MpeWRFFLeXp76IM8V
+eYknPuUcit+OQn+xLkhnXaCr7+7IZ0isM5yMPi8cENxbKHTobBsU4w70iOC
UDaNtw+5I/22EDLlLNsxHmbuy233sYWEa9Ots3ZQzrdX62twrfWD9OmMyszf
4wvLEdjoqq9SVCi+C/gr97XY3VWNrIfzUrC2265ZEqhG8eVwadkfd1asVFv4
P5TLGtSsRv7IXtWtxsw1fGHJ4NnktRe3FWiQPwykp+zpXafRWuhp0FakpcRo
0bkMrL4zXPawQGuR37ssvnpBi85lwHu2TXGBmw71FwOxEYc2eidS/ga/GCi5
UeN0sFCH8iuFwxu9a7c06lBeGNjLZjfiuc5C/8KqiLGjIz2Rn1KoNoodTpV6
It/EwLXdztuU8+HjXV75o0fnughzMlWP9EtApxlYNee6HtWDFNY0vDiZIzGg
+SkD93MLtGF7DMgfOVzZE//irSoD0q+A64Vb8+b3G1B8JSRz7STyssiX3+SC
pg3hXihfTmD8Ir+iM4JyYW6MhaXnEyJ/TfZCOkdBRWf3vpPHKBf6d4g0Rk7I
D+ugXJhjw+Rp7dKvFzHeKI9DpO3dzFnqEG8Uf5Aks2Xun0m5MP/7CN/XNd5I
Zx/pOOhy9GyYEeW9h7yzc/8aSbER+dNLwjbdbPx02Ijy2EOajkw73Z/gg+Lf
J93hgS91Z32QzkdkAvdjWl8U5xnZ8Tzpya0jviiPo0GxIrp/Vz/lwr0jgvVk
/MKq5X7o/rIDGTdY6/1QfToK/kf5ozw6w3f/pp+SHfBHeZGA65g5Tqar/sgf
KdQq2I7UB6D4UsHvLMqF+04KzdGJznFtlAv3iBSC/cqklw0m5I/01fuFcqEv
xMI7IY5yYf6IgJ169+d/aUK+DZCdogfy8AoTyssQCU8bFHcrTCi/XWR1VvbR
gLoAFOccmdsT9KPxBNZfT3j99ZQL76VGcjOOvcC0JuTDt4T353/6hfosJ/wc
qzVZxF/Pvd9cAy148pNbi49kBlro3Je0bUnCukDkWx3hyj+3J9DiXDZ6W+ik
IBS/RPChGPO9JGdzUFSpfTCKc5hwY0zsG4z2f0+mLuq67LmAcmGeVAp9tNKS
535UudIuP9jCt/8AKfiM7A==
     "]], Line3DBox[CompressedData["
1:eJxlln001GkUx6cyiRONkJW85qzJbqmkZI6eOWfVpFdZ1Fq1J3qX07BeyraV
XmyxYTdb02pLNWxitZaitLZI8tJkvL+bITKGlVqRqDU/13PPaZ5z5o/5nHvu
c3/f773397P0PeC+czKLxQoe+00Z+8XmD3B9ZnD4YXrJ3AuPi4g83CBdsH0u
f4KneeZ+KnZ4Qpy1a68Lna0pHxIWB/4e/IR8NxYuD8f4vvRMyw9lTwgTrm1O
eWhQZFvMsmLytEx1kMeJxT9crS4m7jlmp5Sb5lAeVn+L13yohIiFqpuR84LD
W86yS8lqplDk/9gt8NwbXQp1fkK5B6+g6rxTGeQ3orxKxPnWtbqMMDjHgPLU
0PWr/adLgBtSvrJm9prelRLC/I+dRbmsv3friTwJKVDhfOR3u3akDBx5RlRZ
zE5hPbp7FNp39MqhTqwnMu71e7KhHJ4XeYLVA8XW++WkR5VGOZty58T9JYYt
5WQXc0wpX7iW53DBRDquf5QF5Q/T3MTvlkvH9V9nSbljVV9+zX4p1Im+DEuF
JU2HpfC8ZpSf2bYqo6lCnd/eWOQ31baCMO1ggHnMjKqtrokqoE8w3nVxaliO
aSVhwtPRxxs3y/mfJ1SO96EcdUta5C3w1K8iv15UHdR56MC2S0P7qsBf5O3i
hX2ByVXkjcqWAX3Ka7x67HJtqkE3XcozNb0jLFOrCYs5yIfO3nLOtK6BOrUo
t/4i5o/d02qhzqmUB/wp/LkzthbyTKNcWHlldLVeHdSD8cKEFE7sozqoH+Mn
J0aZZIvqyTxVOBe5dIXXy0ZOA2HGq1aT8rJ+bZeNJQ0kkGksHexPu11rvVY2
Qn49ysWFxgWXEhthHlGfsSZhv61vhPyo5/Ep3veOBzSp6X/T13b0ZGYT6IPz
4pvgsaTmfRMxZxoL+aqjezqLHZpBH5y7NLnVYHBIs1o9Jvq+C1IamuFejF91
rDL3IGlR81foMpjmn9UC92L8Yb9prBjnVpgv5P61J7MeJ7YSe+YgL7JN2h2u
JQN/Mf9J1/5+ra9k4AvGl8jPbbAWydTqz9vQXVohkYGeyLnzfby228tBtxmU
v6pY78vZIidMeh/0q2Bob1NCqxzuRS7PuFLobt0G9c+k3NR7B6/1WRv0A97r
bXtA4Dj/OexP9EWacWKNj6Ad9EF/BaFJO8Xb2qF+3Etvr9+wH4xrh/w4p3P9
dZLeXGtX80vXNtC0Xfs5+IXzFXEuQKbr8Rz2xnTKl644N/p6SQfUOYly85l5
g8v2dMD8DpMJ/n2Wo59IvxP22DvKbVomXc4SdoKPGJ+RP9/ctbgT8r+l3NhC
qhFV1wn7/xXll4+4Gc2LfwF1Ig9hN562yX0BvvdQHu+RLDph0QX69FL+KFPD
eJJhF/iI8YdKq2PXB3VB/n8p11jO3Z7c2wV1DlBep9M4a+dSBeQZoZxZG+YK
8HEy7tvIOV8/i1PAewf3T71CM+SnfAW8v3C/iVmbFvppd0N/4j4JCBUPS+y6
wUcO5ac5myUtF7vBF+zDkTb3X+7kdKvNBfM9kD2RH/lLmY1uYms3vO+Q6x7L
Sd2sp4T3CPK+1KCrr+yUoA/yjga3RZJvlDAXOF9HvtySkmilhP2DOkzfEmQY
PRY/rtt/VM/oVgMv2xtK8AX7p3bUz9LJ5SX420F5oEaKAc97BPI8oPx6V0Ts
Q+0RqP8R5X6HRX/v5w3D91IR5Y65t9dFzn0POmRQHhFuvy8v6gP0ZzrlR88c
VI4ksPgf5w/wnFmvuVydF4b8+NmCmA9qdUrDsv9yEbD447oVUH5GsjjarWcK
/+N79cZsN37Khvxi1CH+vlMRf4LHU97m9NjQSMCGPJcp14qOcvzNZSI+i3LB
ralcHQc2f3yf3KXc5F69OTdbQ40Xpvf2nhez+RO6/Q+KIdEp
     "]]}, 
   {RGBColor[0.5, 0.5, 1], EdgeForm[GrayLevel[0.5]], {{}, 
     {RGBColor[0.5, 0.5, 1], EdgeForm[GrayLevel[0.5]], 
      {RGBColor[0.16791, 0., 0.301671], EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {4.015, 0.185748, 9.69}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.1727066608695652, 0.0021134678260869566`, 0.3121154173913044], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {4.0874, 0.189137, 10.12}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.17750332173913044`, 0.004226935652173913, 0.32255983478260875`], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999996`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {4.147600000000001, 0.19106, 9.74}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.18229998260869565`, 0.00634040347826087, 0.33300425217391305`], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {4.237, 0.193756, 7.76}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.18709664347826088`, 0.008453871304347826, 0.3434486695652174], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {4.302300000000001, 0.19700800000000002`, 
             7.949999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.1918933043478261, 0.010567339130434783`, 0.3538930869565218], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {4.3946000000000005`, 0.201832, 7.08}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.1966899652173913, 0.01268080695652174, 0.3643375043478261], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {4.453099999999999, 0.20684399999999997`, 7.16}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.20148662608695653`, 0.014794274782608696`, 0.3747819217391305], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {4.5163, 0.211107, 7.07}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.20628328695652173`, 0.016907742608695653`, 0.3852263391304348], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999996`, 0.}, {0., 0., 0.2020000000000004}}, {0.,
                0., 0.}}], {4.5552, 0.215192, 6.059999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.21107994782608697`, 0.01902121043478261, 0.39567075652173916`], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787980000000024`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {4.6196, 0.220538, 5.83}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.21587660869565217`, 0.021134678260869566`, 0.4061151739130435], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {4.6693999999999996`, 0.225259, 5.18}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.22067326956521738`, 0.023248146086956523`, 0.41655959130434783`], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {4.7362, 0.23475399999999996`, 5.43}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.22546993043478258`, 0.02536161391304348, 0.4270040086956522], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {4.8214, 0.23650899999999997`, 5.639999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.23026659130434782`, 0.027475081739130436`, 0.43744842608695655`], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {4.900499999999999, 0.24018899999999999`, 
             5.6899999999999995`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.23506325217391305`, 0.029588549565217392`, 0.4478928434782609], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.050787980000000024`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {5.022699999999999, 0.24606200000000006`, 
             6.129999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.23985991304347826`, 0.03170201739130435, 0.4583372608695653], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {5.0906, 0.251081, 5.809999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.24465657391304346`, 0.033815485217391306`, 0.4687816782608696], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {5.207699999999999, 0.254776, 5.91}]},
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.24945323478260867`, 0.03592895304347826, 0.47922609565217394`], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {5.2995, 0.26149700000000003`, 
             6.7299999999999995`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.25424989565217393`, 0.03804242086956522, 0.4896705130434783], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {5.4127, 0.26355500000000004`, 7.35}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.25904655652173914`, 0.040155888695652175`, 0.5001149304347826], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20200000000000085`}}, {0.,
                0., 0.}}], {5.5273, 0.267309, 8.27}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.26384321739130434`, 0.04226935652173913, 0.510559347826087],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {5.6284, 0.269164, 8.65}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.26863987826086955`, 0.04438282434782609, 0.5210037652173913], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {5.711499999999999, 0.27226799999999995`, 
             7.879999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.27343653913043475`, 0.046496292173913045`, 0.5314481826086956], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {5.7634, 0.273246, 7.639999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.27823319999999996`, 0.04860976, 0.5418926000000001], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {5.8908000000000005`, 0.278495, 7.639999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.28302986086956516`, 0.05072322782608696, 0.5523370173913044], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787980000000024`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {5.974600000000001, 0.283815, 7.77}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.2878265217391304, 0.052836695652173915`, 0.5627814347826088], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999996`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {6.0295000000000005`, 0.29056599999999994`, 
             7.619999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.29262318260869563`, 0.05495016347826087, 0.5732258521739131], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787980000000024`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {6.023299999999999, 0.29868900000000004`, 
             7.17}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.29741984347826084`, 0.05706363130434783, 0.5836702695652174], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {6.0548, 0.30634599999999995`, 6.219999999999999}]},
           
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.3022165043478261, 0.059177099130434785`, 0.5941146869565218], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {6.143599999999999, 0.31368, 5.65}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.30520197391304343`, 0.06308296347826087, 0.6039596782608696], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {6.2184, 0.319029, 5.58}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.3027538695652174, 0.07236601739130435, 0.6120063913043479], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {6.279299999999999, 0.322659, 4.989999999999999}]},
           
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.3003057652173913, 0.08164907130434783, 0.6200531043478261], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {6.3808, 0.33054999999999995`, 3.8}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2978576608695652, 0.0909321252173913, 0.6280998173913044], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {6.4923, 0.33857, 3.75}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2954095565217391, 0.10021517913043479`, 0.6361465304347826],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {6.5865, 0.34598999999999996`, 3.21}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.292961452173913, 0.10949823304347826`, 0.6441932434782609], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000004, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {6.697499999999999, 0.359888, 
             2.8599999999999994`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.29051334782608695`, 0.11878128695652174`, 0.6522399565217392], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {6.7482, 0.36815800000000004`, 3.}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.28806524347826085`, 0.12806434086956522`, 0.6602866695652174], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {6.8296, 0.376055, 2.87}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.28561713913043474`, 0.1373473947826087, 0.6683333826086957],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {6.9041999999999994`, 0.386997, 3.04}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2831690347826087, 0.14663044869565217`, 0.6763800956521739],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078798000000004, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {7.0328, 0.399946, 3.0200000000000005`}]},
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2807209304347826, 0.15591350260869566`, 0.6844268086956522],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {7.136199999999999, 0.407279, 
             2.9799999999999995`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2782728260869565, 0.16519655652173915`, 0.6924735217391305],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000004, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {7.2698, 0.418598, 3.6800000000000006`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2758247217391304, 0.1744796104347826, 0.7005202347826087], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078798000000004, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {7.3522, 0.426107, 4.33}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2733766173913043, 0.1837626643478261, 0.708566947826087], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {7.4765999999999995`, 0.43167799999999995`, 
             4.949999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.27092851304347826`, 0.19304571826086958`, 0.7166136608695652], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000004, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {7.545299999999999, 0.435179, 5.71}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.26848040869565215`, 0.20232877217391304`, 0.7246603739130435], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078798000000004, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {7.604899999999999, 0.444184, 5.65}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2660323043478261, 0.2116118260869565, 0.7327070869565218], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078798000000004, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {7.7065, 0.448457, 5.42}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2635842, 0.22089488000000002`, 0.7407538], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {7.7995, 0.4530539999999999, 5.279999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2611360956521739, 0.23017793391304348`, 0.7488005130434783],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {7.8931000000000004`, 0.45640800000000004`, 
             4.999999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.25868799130434783`, 0.239460987826087, 0.7568472260869565], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078797999999998, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {8.0615, 0.460294, 4.949999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2562398869565217, 0.24874404173913045`, 0.7648939391304348],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.25040600000000035`, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {8.159, 0.466471, 5.1499999999999995`}]},
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.25379178260869567`, 0.2580270956521739, 0.7729406521739131],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {8.287, 0.472624, 4.989999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.25134367826086956`, 0.26731014956521737`, 0.7809873652173913], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000008, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {8.402000000000001, 0.479762, 
             5.029999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.24889557391304348`, 0.2765932034782609, 0.7890340782608696],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {8.551899999999998, 0.48813199999999995`, 
             5.159999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2464474695652174, 0.28587625739130434`, 0.7970807913043478],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000008, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {8.6917, 0.494188, 5.049999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2439993652173913, 0.29515931130434786`, 0.8051275043478261],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000008, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {8.7883, 0.5011569999999999, 4.969999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.24155126086956522`, 0.3044423652173913, 0.8131742173913044],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2019999999999995}}, {0., 
               0., 0.}}], {8.889700000000001, 0.510869, 5.039999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.23910315652173914`, 0.3137254191304348, 0.8212209304347826],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000008, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {8.994700000000002, 0.518572, 
             4.949999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.23665505217391303`, 0.32300847304347824`, 0.8292676434782609], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000008, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {9.1465, 0.525247, 4.959999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.23624654782608695`, 0.33346248695652175`, 0.835722147826087], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000008, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {9.325600000000001, 0.537522, 3.96}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.23787764347826088`, 0.3450874608695652, 0.8405844434782609],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000008, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {9.450299999999999, 0.542, 4.34}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.23950873913043477`, 0.35671243478260867`, 0.8454467391304348], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {9.5615, 0.5585460000000001, 4.29}]},
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2411398347826087, 0.3683374086956522, 0.8503090347826087], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.2020000000000004}}, {0.,
                0., 0.}}], {9.7187, 0.5669339999999999, 4.549999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.24277093043478262`, 0.37996238260869564`, 0.8551713304347827], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.2020000000000004}}, {0.,
                0., 0.}}], {9.9323, 0.587875, 4.859999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.24440202608695652`, 0.39158735652173915`, 0.8600336260869565], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {10.0361, 0.63052, 5.319999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.24603312173913044`, 0.4032123304347826, 0.8648959217391304],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.2020000000000004}}, {0.,
                0., 0.}}], {10.283700000000001`, 0.602461, 5.66}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.24766421739130434`, 0.41483730434782606`, 0.8697582173913043], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {10.3638, 0.605303, 5.959999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.24929531304347827`, 0.4264622782608696, 0.8746205130434783],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {10.475299999999999`, 0.611446, 6.11}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2509264086956522, 0.43808725217391303`, 0.8794828086956522],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.20199999999999996`}}, {
               0., 0., 0.}}], {10.512500000000001`, 0.613643, 
             5.1499999999999995`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2525575043478261, 0.4497122260869565, 0.8843451043478261], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000008, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.20200000000000018`}}, {
               0., 0., 0.}}], {10.6416, 0.6263289999999999, 3.87}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2541886, 0.4613372, 0.8892074], EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {10.644299999999998`, 0.6352610000000001, 3.51}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2558196956521739, 0.4729621739130435, 0.8940696956521739], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {10.702699999999998`, 0.662714, 2.16}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.25745079130434784`, 0.484587147826087, 0.8989319913043479], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000008, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999985`}}, {0.,
                0., 0.}}], {10.837299999999999`, 0.6689720000000001, 1.65}]},
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[
       0.25908188695652173`, 0.49621212173913043`, 0.9037942869565218], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999985`}}, {0.,
                0., 0.}}], {10.937999999999999`, 0.689892, 
             1.7200000000000002`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.26071298260869563`, 0.5078370956521739, 0.9086565826086956],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999985`}}, {0.,
                0., 0.}}], {11.039800000000001`, 0.7012579999999999, 
             1.6800000000000002`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2623440782608696, 0.5194620695652175, 0.9135188782608695], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000008, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.20199999999999985`}}, {
               0., 0., 0.}}], {11.105699999999999`, 0.712071, 1.58}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2639751739130435, 0.5310870434782609, 0.9183811739130435], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.2019999999999999}}, {0.,
                0., 0.}}], {11.2308, 0.713933, 1.1699999999999997`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2656062695652174, 0.5427120173913044, 0.9232434695652174], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2019999999999999}}, {0., 
               0., 0.}}], {11.3714, 0.736836, 1.1299999999999997`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2672373652173913, 0.5543369913043479, 0.9281057652173913], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             11.6284, 0.7415959999999999, 0.9000000000000001}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.26886846086956523`, 0.5659619652173913, 0.9329680608695652],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000008, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             11.8185, 0.7539690000000001, 0.9200000000000002}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2704995565217391, 0.5775869391304348, 0.9378303565217392], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000008, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             11.991399999999999`, 0.752564, 0.8800000000000001}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.272130652173913, 0.5892119130434783, 0.9426926521739131], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000008, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             12.183499999999999`, 0.7639529999999999, 0.94}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.273761747826087, 0.6008368869565217, 0.947554947826087], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {12.3694, 0.77901, 1.3299999999999998`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2753928434782609, 0.6124618608695652, 0.9524172434782608], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787980000000066`, 0.}, {0., 0., 0.20199999999999985`}}, {
               0., 0., 0.}}], {12.563799999999999`, 0.78789, 
             1.7600000000000002`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.27702393913043477`, 0.6240868347826087, 0.9572795391304347],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {12.8162, 0.785107, 2.33}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.27865503478260867`, 0.6357118086956521, 0.9621418347826087],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {12.975700000000002`, 0.7989270000000002, 
             2.7799999999999994`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2802861304347826, 0.6473367826086956, 0.9670041304347826], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000017, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {13.206499999999998`, 0.8050010000000001, 
             3.2200000000000006`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.2819172260869565, 0.6589617565217392, 0.9718664260869565], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {13.3833, 0.813768, 3.71}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.29510072173913043`, 0.6687224, 0.9737503739130435], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787980000000066`, 0.}, {0., 0., 0.2020000000000004}}, {0.,
                0., 0.}}], {13.649799999999997`, 0.8183360000000001, 4.24}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.31213501739130434`, 0.6778616000000001, 0.9746415391304348],
        EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {13.802899999999996`, 0.8312830000000002, 4.6}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.32916931304347824`, 0.6870008, 0.9755327043478261], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {13.9105, 0.835048, 4.949999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.34620360869565214`, 0.69614, 0.9764238695652174], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {14.068399999999999`, 0.8349070000000001, 
             4.919999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.3632379043478261, 0.7052792, 0.9773150347826087], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000017, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {14.235, 0.839798, 4.9799999999999995`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.3802722, 0.7144184, 0.9782062], EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {14.424499999999997`, 0.8458669999999999, 
             4.869999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.3973064956521739, 0.7235576, 0.9790973652173913], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.2020000000000004}}, {0., 
               0., 0.}}], {14.571899999999998`, 0.8496030000000001, 4.82}]},
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.4143407913043478, 0.7326968, 0.9799885304347826], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999974`}}, {0.,
                0., 0.}}], {14.69, 0.8554450000000002, 3.8999999999999995`}]},
           
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.4313750869565217, 0.741836, 0.9808796956521739], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20200000000000018`}}, {0.,
                0., 0.}}], {14.6729, 0.847977, 2.75}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.4484093826086957, 0.7509752000000001, 0.9817708608695652], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000017, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999996`}}, {0.,
                0., 0.}}], {14.8171, 0.855413, 1.2899999999999998`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.4654436782608696, 0.7601144, 0.9826620260869565], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.20199999999999985`}}, {0.,
                0., 0.}}], {14.844299999999999`, 0.8642780000000001, 1.63}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.4824779739130435, 0.7692536, 0.9835531913043478], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000001, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             14.5467, 1.0166570000000001`, 0.6699999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.4995122695652174, 0.7783928, 0.9844443565217391], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787980000000066`, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             14.381200000000002`, 1.7720289999999999`, 0.13}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.5165465652173913, 0.787532, 0.9853355217391304], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787980000000066`, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             14.3421, 1.7526259999999998`, 0.16000000000000003`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.5335808608695652, 0.7966712, 0.9862266869565217], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.20200000000000004`}}, {
               0., 0., 0.}}], {14.384399999999998`, 1.639508, 
             0.18000000000000002`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.5506151565217391, 0.8058103999999999, 0.987117852173913], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             14.564099999999998`, 1.883673, 0.07}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.567649452173913, 0.8149496, 0.9880090173913043], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             14.672499999999998`, 1.9713729999999998`, 0.06}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.5846837478260869, 0.8240888, 0.9889001826086956], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000017, 0., 0.}, {0., 
               0.05078798000000018, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             14.8792, 2.0761659999999997`, 0.16000000000000003`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.6017180434782609, 0.833228, 0.9897913478260869], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999844`, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             15.0498, 2.0278469999999995`, 0.16000000000000003`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.6187523391304348, 0.8423672, 0.9906825130434783], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000017, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             15.2317, 1.9722119999999999`, 0.13}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.6357866347826087, 0.8515064, 0.9915736782608696], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999844`, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             15.2429, 2.0347989999999996`, 0.15000000000000002`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.6528209304347825, 0.8606456, 0.9924648434782609], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             15.461899999999998`, 2.490388, 0.06}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.6698552260869566, 0.8697848, 0.9933560086956522], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             15.611799999999997`, 2.725147, 0.039999999999999966`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.6868895217391304, 0.878924, 0.9942471739130435], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000017, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.20199999999999999`}}, {
               0., 0., 0.}}], {15.8187, 2.6566300000000003`, 
             0.01999999999999999}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.7039238173913043, 0.8880631999999999, 0.9951383391304348], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000018, 0.}, {0., 0., 0.20199999999999999`}}, {0.,
                0., 0.}}], {16.041599999999995`, 2.659712, 0.03}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.7209581130434783, 0.8972024000000001, 0.9960295043478261], 
       EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000018, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             16.160399999999996`, 2.6585029999999996`, 0.08000000000000002}]},
           
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.7379924086956522, 0.9063416, 0.9969206695652174], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             16.356, 2.6509039999999997`, 0.10000000000000003`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.755026704347826, 0.9154808, 0.9978118347826087], EdgeForm[
       GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504060000000017, 0., 0.}, {0., 
               0.050787979999999955`, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             16.4203, 2.5894319999999995`, 0.10000000000000003`}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}, 
      {RGBColor[0.772061, 0.92462, 0.998703], EdgeForm[GrayLevel[0.5]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             Directive[
              Specularity[
               GrayLevel[1], 20]], {}, {}], 
            GeometricTransformation3DBox[
             GeometricTransformation3DBox[{
               SphereBox[{0, 0, 0}]}, {{{0.2504059999999999, 0., 0.}, {0., 
               0.05078798000000018, 0.}, {0., 0., 0.202}}, {0., 0., 0.}}], {
             16.5353, 2.7053659999999997`, 0.07}]},
           
           ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
            4.503599627370496*^15, -4.503599627370496*^15}}],
          StatusArea[#, 0.03]& ,
          TagBoxNote->"0.03"],
         StyleBox["0.03`", {
           GrayLevel[0], "Graphics3DLabel"}, StripOnInput -> False]],
        Annotation[#, 
         Style[0.03, {
           GrayLevel[0], "Graphics3DLabel"}], "Tooltip"]& ]}}, {}}, 
    StyleBox[{},
     StripOnInput->False,
     Lighting->{{"Ambient", 
        GrayLevel[1]}}]}},
  Axes->True,
  AxesEdge->{{-1, -1}, {1, -1}, {-1, -1}},
  AxesLabel->{
    FormBox[
     StyleBox["\"GDP (trillion USD)\"", Bold, 16, 
      GrayLevel[0.3], StripOnInput -> False], TraditionalForm], 
    FormBox[
     StyleBox["\"MB (trillion USD)\"", Bold, 16, 
      GrayLevel[0.3], StripOnInput -> False], TraditionalForm], 
    FormBox[
     StyleBox["\"YIELD (%)\"", Bold, 16, 
      GrayLevel[0.3], StripOnInput -> False], TraditionalForm]},
  AxesStyle->GrayLevel[0.2],
  BaseStyle->{FontFamily -> "Helvetica"},
  BoxRatios->{1, 1, 1},
  BoxStyle->GrayLevel[0.2],
  Boxed->{Bottom, Left, Back},
  FaceGrids->None,
  ImagePadding->100,
  ImageSize->550,
  Lighting->"Neutral",
  PlotRangePadding->None,
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellGroupingRules->"InputGrouping"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spotting a Liquidity Trap", "Section"],

Cell["\<\
The chart below illustrates the relationship between US monetary base \
velocity and interest rates since 1984. In economics, few theoretical \
relationships hold up so well. As mentioned earlier, liquidity traps occur \
when interest rates bottom out and cash is hoarded. As a result, the \
relationship between velocity and interest rates flattens at low rates \
because money stock increases produce a proportional decline in velocity \
without requiring any further decline in yields.\
\>", "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`n$$ = 106, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`n$$], 106, "Time"}, 1, 116, 1}}, Typeset`size$$ = {
    768., {227.125, 232.875}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`n$63856$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`n$$ = 106}, 
      "ControllerVariables" :> {
        Hold[$CellContext`n$$, $CellContext`n$63856$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Grid[{
         Map[
         Style[#, FontFamily -> "Arial", FontSize -> 10]& , {
          "3-Month Treasury Bill", "Gross Domestic Product", 
           "St. Louis Adjusted"}], 
         Map[
         Style[#, FontFamily -> "Arial", FontSize -> 10]& , {
          "Secondary Market Rate", "Seasonally Adjusted Annual Rate", 
           "Monetary Base"}], {
          
          DateListPlot[$CellContext`neededyield, {
           Joined -> True, AspectRatio -> Rational[1, 4], ImageSize -> 250, 
            Frame -> True, FrameStyle -> GrayLevel[0.3], 
            FrameTicks -> {Automatic, False}, Axes -> {True, True}, Ticks -> 
            None, BaseStyle -> (FontFamily -> "Arial"), PlotRange -> All, 
            PlotStyle -> {
              Thickness[Large], {
               Hue[0.55, 1, 0.7], 
               Hue[0.06, 1, 0.9], 
               Hue[0.25, 1, 0.55], 
               Hue[0.11, 0.9, 0.85], 
               Hue[0.5, 1, 0.5], 
               Hue[0.2, 1, 0.7], 
               Hue[0.08, 1, 0.7], 
               Hue[0.5, 0.8, 0.75], 
               Hue[0.45, 1, 0.5], 
               Hue[0.6, 0.5, 0.9]}}, Filling -> Axis, FillingStyle -> {
              RGBColor[
              0.3333333333333333, 0.6599999999999998, 0.7999999999999999], 
              RGBColor[
              0.9333333333333333, 0.5493333333333333, 0.3333333333333333], 
              RGBColor[0.5166666666666666, 0.7, 0.3333333333333333], 
              RGBColor[0.9, 0.7265999999999999, 0.38999999999999996`], 
              RGBColor[
              0.3333333333333333, 0.6666666666666666, 0.6666666666666666], 
              RGBColor[
              0.7066666666666666, 0.7999999999999999, 0.3333333333333333], 
              RGBColor[
              0.7999999999999999, 0.5573333333333332, 0.3333333333333333], 
              RGBColor[
              0.4333333333333333, 0.8333333333333334, 0.8333333333333334], 
              RGBColor[
              0.3333333333333333, 0.6666666666666666, 0.5666666666666667], 
              RGBColor[
              0.6333333333333333, 0.7533333333333335, 0.9333333333333333]}, 
            PlotRangeClipping -> True}, Epilog -> {
             Lighter[Red], 
             PointSize[Large], 
             Point[
              Part[$CellContext`neededyield, $CellContext`n$$]], 
             Line[
              Map[Scaled[#, {
                 Part[
                  Part[$CellContext`neededyield, $CellContext`n$$], 1], 
                 0}]& , {{0, 0}, {0, 1}}]]}], 
          
          DateListPlot[$CellContext`neededgdp, {
           Joined -> True, AspectRatio -> Rational[1, 4], ImageSize -> 250, 
            Frame -> True, FrameStyle -> GrayLevel[0.3], 
            FrameTicks -> {Automatic, False}, Axes -> {True, True}, Ticks -> 
            None, BaseStyle -> (FontFamily -> "Arial"), PlotRange -> All, 
            PlotStyle -> {
              Thickness[Large], {
               Hue[0.55, 1, 0.7], 
               Hue[0.06, 1, 0.9], 
               Hue[0.25, 1, 0.55], 
               Hue[0.11, 0.9, 0.85], 
               Hue[0.5, 1, 0.5], 
               Hue[0.2, 1, 0.7], 
               Hue[0.08, 1, 0.7], 
               Hue[0.5, 0.8, 0.75], 
               Hue[0.45, 1, 0.5], 
               Hue[0.6, 0.5, 0.9]}}, Filling -> Axis, FillingStyle -> {
              RGBColor[
              0.3333333333333333, 0.6599999999999998, 0.7999999999999999], 
              RGBColor[
              0.9333333333333333, 0.5493333333333333, 0.3333333333333333], 
              RGBColor[0.5166666666666666, 0.7, 0.3333333333333333], 
              RGBColor[0.9, 0.7265999999999999, 0.38999999999999996`], 
              RGBColor[
              0.3333333333333333, 0.6666666666666666, 0.6666666666666666], 
              RGBColor[
              0.7066666666666666, 0.7999999999999999, 0.3333333333333333], 
              RGBColor[
              0.7999999999999999, 0.5573333333333332, 0.3333333333333333], 
              RGBColor[
              0.4333333333333333, 0.8333333333333334, 0.8333333333333334], 
              RGBColor[
              0.3333333333333333, 0.6666666666666666, 0.5666666666666667], 
              RGBColor[
              0.6333333333333333, 0.7533333333333335, 0.9333333333333333]}, 
            PlotRangeClipping -> True}, Epilog -> {
             Lighter[Red], 
             PointSize[Large], 
             Point[
              Part[$CellContext`neededgdp, $CellContext`n$$]], 
             Line[
              Map[Scaled[#, {
                 Part[
                  Part[$CellContext`neededgdp, $CellContext`n$$], 1], 
                 0}]& , {{0, 0}, {0, 2}}]]}], 
          
          DateListPlot[$CellContext`neededmb, {
           Joined -> True, AspectRatio -> Rational[1, 4], ImageSize -> 250, 
            Frame -> True, FrameStyle -> GrayLevel[0.3], 
            FrameTicks -> {Automatic, False}, Axes -> {True, True}, Ticks -> 
            None, BaseStyle -> (FontFamily -> "Arial"), PlotRange -> All, 
            PlotStyle -> {
              Thickness[Large], {
               Hue[0.55, 1, 0.7], 
               Hue[0.06, 1, 0.9], 
               Hue[0.25, 1, 0.55], 
               Hue[0.11, 0.9, 0.85], 
               Hue[0.5, 1, 0.5], 
               Hue[0.2, 1, 0.7], 
               Hue[0.08, 1, 0.7], 
               Hue[0.5, 0.8, 0.75], 
               Hue[0.45, 1, 0.5], 
               Hue[0.6, 0.5, 0.9]}}, Filling -> Axis, FillingStyle -> {
              RGBColor[
              0.3333333333333333, 0.6599999999999998, 0.7999999999999999], 
              RGBColor[
              0.9333333333333333, 0.5493333333333333, 0.3333333333333333], 
              RGBColor[0.5166666666666666, 0.7, 0.3333333333333333], 
              RGBColor[0.9, 0.7265999999999999, 0.38999999999999996`], 
              RGBColor[
              0.3333333333333333, 0.6666666666666666, 0.6666666666666666], 
              RGBColor[
              0.7066666666666666, 0.7999999999999999, 0.3333333333333333], 
              RGBColor[
              0.7999999999999999, 0.5573333333333332, 0.3333333333333333], 
              RGBColor[
              0.4333333333333333, 0.8333333333333334, 0.8333333333333334], 
              RGBColor[
              0.3333333333333333, 0.6666666666666666, 0.5666666666666667], 
              RGBColor[
              0.6333333333333333, 0.7533333333333335, 0.9333333333333333]}, 
            PlotRangeClipping -> True}, Epilog -> {
             Lighter[Red], 
             PointSize[Large], 
             Point[
              Part[$CellContext`neededmb, $CellContext`n$$]], 
             Line[
              Map[Scaled[#, {
                 Part[
                  Part[$CellContext`neededmb, $CellContext`n$$], 1], 0}]& , {{
               0, 0}, {0, 1}}]]}]}, {""}, {
          Row[{
            Show[
             ListLinePlot[
              Part[
               Transpose[{$CellContext`velocitymb, 
                 Part[$CellContext`neededyield, All, 2]}], 
               Span[1, $CellContext`n$$]], PlotRange -> {{5, 22}, {0, 10}}, 
              PlotRangePadding -> 1, Frame -> True, 
              FrameLabel -> {
               "Velocity of Monetary Base", "3-Month Treasury Bill Yield"}, 
              PlotStyle -> {Thick, Gray, 
                Opacity[0.5]}, BaseStyle -> (FontFamily -> "Verdana"), Epilog -> 
              With[{$CellContext`pt$ = Part[
                   Transpose[{$CellContext`velocitymb, 
                    
                    Part[$CellContext`neededyield, All, 
                    2]}], $CellContext`n$$]}, {Gray, 
                 Arrowheads[Medium], Dashed, 
                 Arrow[{
                   Scaled[{0.2, 0.8}], $CellContext`pt$}], 
                 Style[
                  Text[
                   Framed[
                    ToUpperCase[
                    DateString[
                    Part[$CellContext`gdpDates, $CellContext`n$$], {
                    "MonthName", " \[FilledSmallCircle] ", "Year"}]], 
                    FrameMargins -> 8, Background -> Lighter[
                    ColorData[68][1]]], 
                   Scaled[{0.2, 0.8}], {Center, Bottom}], Bold, 14, White], 
                 Dashing[{}], Red, 
                 Circle[$CellContext`pt$, 
                  Offset[20]], 
                 Point[$CellContext`pt$]}], ImageSize -> 480], 
             ListPlot[
              Transpose[{$CellContext`velocitymb, 
                Part[$CellContext`neededyield, All, 2]}], PlotRange -> All, 
              PlotStyle -> {
                AbsolutePointSize[8], 
                Opacity[0.5], 
                ColorData[68, "ColorList"]}]], 
            Spacer[80], 
            Column[{
              AngularGauge[
               Part[$CellContext`velocitymb, $CellContext`n$$], {0, 25}, 
               ImageSize -> 150, ScaleOrigin -> {Pi + Pi/6, (-Pi)/6}, 
               GaugeStyle -> {
                 ColorData[68, "ColorList"], 
                 Lighter[
                  ColorData[68, "ColorList"], 0.7]}, 
               ScaleRanges -> {{0, 10}, {10, 20}, {20, 25}}], 
              Style[
              "Velocity of Monetary Base", FontFamily -> "Arial", FontSize -> 
               12], 
              AngularGauge[
               Part[
                Part[$CellContext`neededyield, All, 2], $CellContext`n$$], {0,
                25}, ImageSize -> 150, ScaleOrigin -> {Pi + Pi/6, (-Pi)/6}, 
               GaugeStyle -> {
                 ColorData[68, "ColorList"], 
                 Lighter[
                  ColorData[68, "ColorList"], 0.7]}, 
               ScaleRanges -> {{0, 10}, {10, 20}, {20, 25}}], 
              Style[
              "3-Month Treasury Bill Yield", FontFamily -> "Arial", FontSize -> 
               12]}, Alignment -> Center]}], SpanFromLeft, SpanFromLeft}}, 
        Alignment -> {Center, Center}], 
      "Specifications" :> {{{$CellContext`n$$, 106, "Time"}, 1, 116, 1, 
         ControlType -> Slider, ImageSize -> {500, 20}}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{813., {270., 275.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`neededyield = {{{1984, 4, 1, 0, 0, 0.}, 
          9.69}, {{1984, 7, 1, 0, 0, 0.}, 10.12}, {{1984, 10, 1, 0, 0, 0.}, 
          9.74}, {{1985, 1, 1, 0, 0, 0.}, 7.76}, {{1985, 4, 1, 0, 0, 0.}, 
          7.95}, {{1985, 7, 1, 0, 0, 0.}, 7.08}, {{1985, 10, 1, 0, 0, 0.}, 
          7.16}, {{1986, 1, 1, 0, 0, 0.}, 7.07}, {{1986, 4, 1, 0, 0, 0.}, 
          6.06}, {{1986, 7, 1, 0, 0, 0.}, 5.83}, {{1986, 10, 1, 0, 0, 0.}, 
          5.18}, {{1987, 1, 1, 0, 0, 0.}, 5.43}, {{1987, 4, 1, 0, 0, 0.}, 
          5.64}, {{1987, 7, 1, 0, 0, 0.}, 5.69}, {{1987, 10, 1, 0, 0, 0.}, 
          6.13}, {{1988, 1, 1, 0, 0, 0.}, 5.81}, {{1988, 4, 1, 0, 0, 0.}, 
          5.91}, {{1988, 7, 1, 0, 0, 0.}, 6.73}, {{1988, 10, 1, 0, 0, 0.}, 
          7.35}, {{1989, 1, 1, 0, 0, 0.}, 8.27}, {{1989, 4, 1, 0, 0, 0.}, 
          8.65}, {{1989, 7, 1, 0, 0, 0.}, 7.88}, {{1989, 10, 1, 0, 0, 0.}, 
          7.64}, {{1990, 1, 1, 0, 0, 0.}, 7.64}, {{1990, 4, 1, 0, 0, 0.}, 
          7.77}, {{1990, 7, 1, 0, 0, 0.}, 7.62}, {{1990, 10, 1, 0, 0, 0.}, 
          7.17}, {{1991, 1, 1, 0, 0, 0.}, 6.22}, {{1991, 4, 1, 0, 0, 0.}, 
          5.65}, {{1991, 7, 1, 0, 0, 0.}, 5.58}, {{1991, 10, 1, 0, 0, 0.}, 
          4.99}, {{1992, 1, 1, 0, 0, 0.}, 3.8}, {{1992, 4, 1, 0, 0, 0.}, 
          3.75}, {{1992, 7, 1, 0, 0, 0.}, 3.21}, {{1992, 10, 1, 0, 0, 0.}, 
          2.86}, {{1993, 1, 1, 0, 0, 0.}, 3.}, {{1993, 4, 1, 0, 0, 0.}, 
          2.87}, {{1993, 7, 1, 0, 0, 0.}, 3.04}, {{1993, 10, 1, 0, 0, 0.}, 
          3.02}, {{1994, 1, 1, 0, 0, 0.}, 2.98}, {{1994, 4, 1, 0, 0, 0.}, 
          3.68}, {{1994, 7, 1, 0, 0, 0.}, 4.33}, {{1994, 10, 1, 0, 0, 0.}, 
          4.95}, {{1995, 1, 1, 0, 0, 0.}, 5.71}, {{1995, 4, 1, 0, 0, 0.}, 
          5.65}, {{1995, 7, 1, 0, 0, 0.}, 5.42}, {{1995, 10, 1, 0, 0, 0.}, 
          5.28}, {{1996, 1, 1, 0, 0, 0.}, 5.}, {{1996, 4, 1, 0, 0, 0.}, 
          4.95}, {{1996, 7, 1, 0, 0, 0.}, 5.15}, {{1996, 10, 1, 0, 0, 0.}, 
          4.99}, {{1997, 1, 1, 0, 0, 0.}, 5.03}, {{1997, 4, 1, 0, 0, 0.}, 
          5.16}, {{1997, 7, 1, 0, 0, 0.}, 5.05}, {{1997, 10, 1, 0, 0, 0.}, 
          4.97}, {{1998, 1, 1, 0, 0, 0.}, 5.04}, {{1998, 4, 1, 0, 0, 0.}, 
          4.95}, {{1998, 7, 1, 0, 0, 0.}, 4.96}, {{1998, 10, 1, 0, 0, 0.}, 
          3.96}, {{1999, 1, 1, 0, 0, 0.}, 4.34}, {{1999, 4, 1, 0, 0, 0.}, 
          4.29}, {{1999, 7, 1, 0, 0, 0.}, 4.55}, {{1999, 10, 1, 0, 0, 0.}, 
          4.86}, {{2000, 1, 1, 0, 0, 0.}, 5.32}, {{2000, 4, 1, 0, 0, 0.}, 
          5.66}, {{2000, 7, 1, 0, 0, 0.}, 5.96}, {{2000, 10, 1, 0, 0, 0.}, 
          6.11}, {{2001, 1, 1, 0, 0, 0.}, 5.15}, {{2001, 4, 1, 0, 0, 0.}, 
          3.87}, {{2001, 7, 1, 0, 0, 0.}, 3.51}, {{2001, 10, 1, 0, 0, 0.}, 
          2.16}, {{2002, 1, 1, 0, 0, 0.}, 1.65}, {{2002, 4, 1, 0, 0, 0.}, 
          1.72}, {{2002, 7, 1, 0, 0, 0.}, 1.68}, {{2002, 10, 1, 0, 0, 0.}, 
          1.58}, {{2003, 1, 1, 0, 0, 0.}, 1.17}, {{2003, 4, 1, 0, 0, 0.}, 
          1.13}, {{2003, 7, 1, 0, 0, 0.}, 0.9}, {{2003, 10, 1, 0, 0, 0.}, 
          0.92}, {{2004, 1, 1, 0, 0, 0.}, 0.88}, {{2004, 4, 1, 0, 0, 0.}, 
          0.94}, {{2004, 7, 1, 0, 0, 0.}, 1.33}, {{2004, 10, 1, 0, 0, 0.}, 
          1.76}, {{2005, 1, 1, 0, 0, 0.}, 2.33}, {{2005, 4, 1, 0, 0, 0.}, 
          2.78}, {{2005, 7, 1, 0, 0, 0.}, 3.22}, {{2005, 10, 1, 0, 0, 0.}, 
          3.71}, {{2006, 1, 1, 0, 0, 0.}, 4.24}, {{2006, 4, 1, 0, 0, 0.}, 
          4.6}, {{2006, 7, 1, 0, 0, 0.}, 4.95}, {{2006, 10, 1, 0, 0, 0.}, 
          4.92}, {{2007, 1, 1, 0, 0, 0.}, 4.98}, {{2007, 4, 1, 0, 0, 0.}, 
          4.87}, {{2007, 7, 1, 0, 0, 0.}, 4.82}, {{2007, 10, 1, 0, 0, 0.}, 
          3.9}, {{2008, 1, 1, 0, 0, 0.}, 2.75}, {{2008, 4, 1, 0, 0, 0.}, 
          1.29}, {{2008, 7, 1, 0, 0, 0.}, 1.63}, {{2008, 10, 1, 0, 0, 0.}, 
          0.67}, {{2009, 1, 1, 0, 0, 0.}, 0.13}, {{2009, 4, 1, 0, 0, 0.}, 
          0.16}, {{2009, 7, 1, 0, 0, 0.}, 0.18}, {{2009, 10, 1, 0, 0, 0.}, 
          0.07}, {{2010, 1, 1, 0, 0, 0.}, 0.06}, {{2010, 4, 1, 0, 0, 0.}, 
          0.16}, {{2010, 7, 1, 0, 0, 0.}, 0.16}, {{2010, 10, 1, 0, 0, 0.}, 
          0.13}, {{2011, 1, 1, 0, 0, 0.}, 0.15}, {{2011, 4, 1, 0, 0, 0.}, 
          0.06}, {{2011, 7, 1, 0, 0, 0.}, 0.04}, {{2011, 10, 1, 0, 0, 0.}, 
          0.02}, {{2012, 1, 1, 0, 0, 0.}, 0.03}, {{2012, 4, 1, 0, 0, 0.}, 
          0.08}, {{2012, 7, 1, 0, 0, 0.}, 0.1}, {{2012, 10, 1, 0, 0, 0.}, 
          0.1}, {{2013, 1, 1, 0, 0, 0.}, 0.07}}, $CellContext`neededgdp = {{{
          1984, 4, 1, 0, 0, 0.}, 4015.}, {{1984, 7, 1, 0, 0, 0.}, 4087.4}, {{
          1984, 10, 1, 0, 0, 0.}, 4147.6}, {{1985, 1, 1, 0, 0, 0.}, 4237.}, {{
          1985, 4, 1, 0, 0, 0.}, 4302.3}, {{1985, 7, 1, 0, 0, 0.}, 4394.6}, {{
          1985, 10, 1, 0, 0, 0.}, 4453.1}, {{1986, 1, 1, 0, 0, 0.}, 
          4516.3}, {{1986, 4, 1, 0, 0, 0.}, 4555.2}, {{1986, 7, 1, 0, 0, 0.}, 
          4619.6}, {{1986, 10, 1, 0, 0, 0.}, 4669.4}, {{1987, 1, 1, 0, 0, 0.},
           4736.2}, {{1987, 4, 1, 0, 0, 0.}, 4821.4}, {{1987, 7, 1, 0, 0, 0.},
           4900.5}, {{1987, 10, 1, 0, 0, 0.}, 5022.7}, {{
          1988, 1, 1, 0, 0, 0.}, 5090.6}, {{1988, 4, 1, 0, 0, 0.}, 5207.7}, {{
          1988, 7, 1, 0, 0, 0.}, 5299.5}, {{1988, 10, 1, 0, 0, 0.}, 
          5412.7}, {{1989, 1, 1, 0, 0, 0.}, 5527.3}, {{1989, 4, 1, 0, 0, 0.}, 
          5628.4}, {{1989, 7, 1, 0, 0, 0.}, 5711.5}, {{1989, 10, 1, 0, 0, 0.},
           5763.4}, {{1990, 1, 1, 0, 0, 0.}, 5890.8}, {{1990, 4, 1, 0, 0, 0.},
           5974.6}, {{1990, 7, 1, 0, 0, 0.}, 6029.5}, {{
          1990, 10, 1, 0, 0, 0.}, 6023.3}, {{1991, 1, 1, 0, 0, 0.}, 
          6054.8}, {{1991, 4, 1, 0, 0, 0.}, 6143.6}, {{1991, 7, 1, 0, 0, 0.}, 
          6218.4}, {{1991, 10, 1, 0, 0, 0.}, 6279.3}, {{1992, 1, 1, 0, 0, 0.},
           6380.8}, {{1992, 4, 1, 0, 0, 0.}, 6492.3}, {{1992, 7, 1, 0, 0, 0.},
           6586.5}, {{1992, 10, 1, 0, 0, 0.}, 6697.5}, {{
          1993, 1, 1, 0, 0, 0.}, 6748.2}, {{1993, 4, 1, 0, 0, 0.}, 6829.6}, {{
          1993, 7, 1, 0, 0, 0.}, 6904.2}, {{1993, 10, 1, 0, 0, 0.}, 
          7032.8}, {{1994, 1, 1, 0, 0, 0.}, 7136.2}, {{1994, 4, 1, 0, 0, 0.}, 
          7269.8}, {{1994, 7, 1, 0, 0, 0.}, 7352.2}, {{1994, 10, 1, 0, 0, 0.},
           7476.6}, {{1995, 1, 1, 0, 0, 0.}, 7545.3}, {{1995, 4, 1, 0, 0, 0.},
           7604.9}, {{1995, 7, 1, 0, 0, 0.}, 7706.5}, {{
          1995, 10, 1, 0, 0, 0.}, 7799.5}, {{1996, 1, 1, 0, 0, 0.}, 
          7893.1}, {{1996, 4, 1, 0, 0, 0.}, 8061.5}, {{1996, 7, 1, 0, 0, 0.}, 
          8159.}, {{1996, 10, 1, 0, 0, 0.}, 8287.}, {{1997, 1, 1, 0, 0, 0.}, 
          8402.}, {{1997, 4, 1, 0, 0, 0.}, 8551.9}, {{1997, 7, 1, 0, 0, 0.}, 
          8691.7}, {{1997, 10, 1, 0, 0, 0.}, 8788.3}, {{1998, 1, 1, 0, 0, 0.},
           8889.7}, {{1998, 4, 1, 0, 0, 0.}, 8994.7}, {{1998, 7, 1, 0, 0, 0.},
           9146.5}, {{1998, 10, 1, 0, 0, 0.}, 9325.6}, {{
          1999, 1, 1, 0, 0, 0.}, 9450.3}, {{1999, 4, 1, 0, 0, 0.}, 9561.5}, {{
          1999, 7, 1, 0, 0, 0.}, 9718.7}, {{1999, 10, 1, 0, 0, 0.}, 
          9932.3}, {{2000, 1, 1, 0, 0, 0.}, 10036.1}, {{2000, 4, 1, 0, 0, 0.},
           10283.7}, {{2000, 7, 1, 0, 0, 0.}, 10363.8}, {{
          2000, 10, 1, 0, 0, 0.}, 10475.3}, {{2001, 1, 1, 0, 0, 0.}, 
          10512.5}, {{2001, 4, 1, 0, 0, 0.}, 10641.6}, {{
          2001, 7, 1, 0, 0, 0.}, 10644.3}, {{2001, 10, 1, 0, 0, 0.}, 
          10702.7}, {{2002, 1, 1, 0, 0, 0.}, 10837.3}, {{
          2002, 4, 1, 0, 0, 0.}, 10938.}, {{2002, 7, 1, 0, 0, 0.}, 
          11039.8}, {{2002, 10, 1, 0, 0, 0.}, 11105.7}, {{
          2003, 1, 1, 0, 0, 0.}, 11230.8}, {{2003, 4, 1, 0, 0, 0.}, 
          11371.4}, {{2003, 7, 1, 0, 0, 0.}, 11628.4}, {{
          2003, 10, 1, 0, 0, 0.}, 11818.5}, {{2004, 1, 1, 0, 0, 0.}, 
          11991.4}, {{2004, 4, 1, 0, 0, 0.}, 12183.5}, {{
          2004, 7, 1, 0, 0, 0.}, 12369.4}, {{2004, 10, 1, 0, 0, 0.}, 
          12563.8}, {{2005, 1, 1, 0, 0, 0.}, 12816.2}, {{
          2005, 4, 1, 0, 0, 0.}, 12975.7}, {{2005, 7, 1, 0, 0, 0.}, 
          13206.5}, {{2005, 10, 1, 0, 0, 0.}, 13383.3}, {{
          2006, 1, 1, 0, 0, 0.}, 13649.8}, {{2006, 4, 1, 0, 0, 0.}, 
          13802.9}, {{2006, 7, 1, 0, 0, 0.}, 13910.5}, {{
          2006, 10, 1, 0, 0, 0.}, 14068.4}, {{2007, 1, 1, 0, 0, 0.}, 
          14235.}, {{2007, 4, 1, 0, 0, 0.}, 14424.5}, {{2007, 7, 1, 0, 0, 0.},
           14571.9}, {{2007, 10, 1, 0, 0, 0.}, 14690.}, {{
          2008, 1, 1, 0, 0, 0.}, 14672.9}, {{2008, 4, 1, 0, 0, 0.}, 
          14817.1}, {{2008, 7, 1, 0, 0, 0.}, 14844.3}, {{
          2008, 10, 1, 0, 0, 0.}, 14546.7}, {{2009, 1, 1, 0, 0, 0.}, 
          14381.2}, {{2009, 4, 1, 0, 0, 0.}, 14342.1}, {{
          2009, 7, 1, 0, 0, 0.}, 14384.4}, {{2009, 10, 1, 0, 0, 0.}, 
          14564.1}, {{2010, 1, 1, 0, 0, 0.}, 14672.5}, {{
          2010, 4, 1, 0, 0, 0.}, 14879.2}, {{2010, 7, 1, 0, 0, 0.}, 
          15049.8}, {{2010, 10, 1, 0, 0, 0.}, 15231.7}, {{
          2011, 1, 1, 0, 0, 0.}, 15242.9}, {{2011, 4, 1, 0, 0, 0.}, 
          15461.9}, {{2011, 7, 1, 0, 0, 0.}, 15611.8}, {{
          2011, 10, 1, 0, 0, 0.}, 15818.7}, {{2012, 1, 1, 0, 0, 0.}, 
          16041.6}, {{2012, 4, 1, 0, 0, 0.}, 16160.4}, {{
          2012, 7, 1, 0, 0, 0.}, 16356.}, {{2012, 10, 1, 0, 0, 0.}, 
          16420.3}, {{2013, 1, 1, 0, 0, 0.}, 
          16535.3}}, $CellContext`neededmb = {{{1984, 4, 11, 0, 0, 0.}, 
          185.748}, {{1984, 7, 4, 0, 0, 0.}, 189.137}, {{
          1984, 10, 10, 0, 0, 0.}, 191.06}, {{1985, 1, 2, 0, 0, 0.}, 
          193.756}, {{1985, 4, 10, 0, 0, 0.}, 197.008}, {{
          1985, 7, 3, 0, 0, 0.}, 201.832}, {{1985, 10, 9, 0, 0, 0.}, 
          206.844}, {{1986, 1, 1, 0, 0, 0.}, 211.107}, {{
          1986, 4, 9, 0, 0, 0.}, 215.192}, {{1986, 7, 2, 0, 0, 0.}, 
          220.538}, {{1986, 10, 8, 0, 0, 0.}, 225.259}, {{
          1987, 1, 14, 0, 0, 0.}, 234.754}, {{1987, 4, 8, 0, 0, 0.}, 
          236.509}, {{1987, 7, 1, 0, 0, 0.}, 240.189}, {{
          1987, 10, 7, 0, 0, 0.}, 246.062}, {{1988, 1, 13, 0, 0, 0.}, 
          251.081}, {{1988, 4, 6, 0, 0, 0.}, 254.776}, {{
          1988, 7, 13, 0, 0, 0.}, 261.497}, {{1988, 10, 5, 0, 0, 0.}, 
          263.555}, {{1989, 1, 11, 0, 0, 0.}, 267.309}, {{
          1989, 4, 5, 0, 0, 0.}, 269.164}, {{1989, 7, 12, 0, 0, 0.}, 
          272.268}, {{1989, 10, 4, 0, 0, 0.}, 273.246}, {{
          1990, 1, 10, 0, 0, 0.}, 278.495}, {{1990, 4, 4, 0, 0, 0.}, 
          283.815}, {{1990, 7, 11, 0, 0, 0.}, 290.566}, {{
          1990, 10, 3, 0, 0, 0.}, 298.689}, {{1991, 1, 9, 0, 0, 0.}, 
          306.346}, {{1991, 4, 3, 0, 0, 0.}, 313.68}, {{
          1991, 7, 10, 0, 0, 0.}, 319.029}, {{1991, 10, 2, 0, 0, 0.}, 
          322.659}, {{1992, 1, 8, 0, 0, 0.}, 330.55}, {{1992, 4, 1, 0, 0, 0.},
           338.57}, {{1992, 7, 8, 0, 0, 0.}, 345.99}, {{
          1992, 10, 14, 0, 0, 0.}, 359.888}, {{1993, 1, 6, 0, 0, 0.}, 
          368.158}, {{1993, 4, 14, 0, 0, 0.}, 376.055}, {{
          1993, 7, 7, 0, 0, 0.}, 386.997}, {{1993, 10, 13, 0, 0, 0.}, 
          399.946}, {{1994, 1, 5, 0, 0, 0.}, 407.279}, {{
          1994, 4, 13, 0, 0, 0.}, 418.598}, {{1994, 7, 6, 0, 0, 0.}, 
          426.107}, {{1994, 10, 12, 0, 0, 0.}, 431.678}, {{
          1995, 1, 4, 0, 0, 0.}, 435.179}, {{1995, 4, 12, 0, 0, 0.}, 
          444.184}, {{1995, 7, 5, 0, 0, 0.}, 448.457}, {{
          1995, 10, 11, 0, 0, 0.}, 453.054}, {{1996, 1, 3, 0, 0, 0.}, 
          456.408}, {{1996, 4, 10, 0, 0, 0.}, 460.294}, {{
          1996, 7, 3, 0, 0, 0.}, 466.471}, {{1996, 10, 9, 0, 0, 0.}, 
          472.624}, {{1997, 1, 1, 0, 0, 0.}, 479.762}, {{
          1997, 4, 9, 0, 0, 0.}, 488.132}, {{1997, 7, 2, 0, 0, 0.}, 
          494.188}, {{1997, 10, 8, 0, 0, 0.}, 501.157}, {{
          1998, 1, 14, 0, 0, 0.}, 510.869}, {{1998, 4, 8, 0, 0, 0.}, 
          518.572}, {{1998, 7, 1, 0, 0, 0.}, 525.247}, {{
          1998, 10, 7, 0, 0, 0.}, 537.522}, {{1999, 1, 13, 0, 0, 0.}, 
          542.}, {{1999, 4, 7, 0, 0, 0.}, 558.546}, {{1999, 7, 14, 0, 0, 0.}, 
          566.934}, {{1999, 10, 6, 0, 0, 0.}, 587.875}, {{
          2000, 1, 12, 0, 0, 0.}, 630.52}, {{2000, 4, 5, 0, 0, 0.}, 
          602.461}, {{2000, 7, 12, 0, 0, 0.}, 605.303}, {{
          2000, 10, 4, 0, 0, 0.}, 611.446}, {{2001, 1, 10, 0, 0, 0.}, 
          613.643}, {{2001, 4, 4, 0, 0, 0.}, 626.329}, {{
          2001, 7, 11, 0, 0, 0.}, 635.261}, {{2001, 10, 3, 0, 0, 0.}, 
          662.714}, {{2002, 1, 9, 0, 0, 0.}, 668.972}, {{
          2002, 4, 3, 0, 0, 0.}, 689.892}, {{2002, 7, 10, 0, 0, 0.}, 
          701.258}, {{2002, 10, 2, 0, 0, 0.}, 712.071}, {{
          2003, 1, 8, 0, 0, 0.}, 713.933}, {{2003, 4, 2, 0, 0, 0.}, 
          736.836}, {{2003, 7, 9, 0, 0, 0.}, 741.596}, {{
          2003, 10, 1, 0, 0, 0.}, 753.969}, {{2004, 1, 7, 0, 0, 0.}, 
          752.564}, {{2004, 4, 14, 0, 0, 0.}, 763.953}, {{
          2004, 7, 7, 0, 0, 0.}, 779.01}, {{2004, 10, 13, 0, 0, 0.}, 
          787.89}, {{2005, 1, 5, 0, 0, 0.}, 785.107}, {{
          2005, 4, 13, 0, 0, 0.}, 798.927}, {{2005, 7, 6, 0, 0, 0.}, 
          805.001}, {{2005, 10, 12, 0, 0, 0.}, 813.768}, {{
          2006, 1, 4, 0, 0, 0.}, 818.336}, {{2006, 4, 12, 0, 0, 0.}, 
          831.283}, {{2006, 7, 5, 0, 0, 0.}, 835.048}, {{
          2006, 10, 11, 0, 0, 0.}, 834.907}, {{2007, 1, 3, 0, 0, 0.}, 
          839.798}, {{2007, 4, 11, 0, 0, 0.}, 845.867}, {{
          2007, 7, 4, 0, 0, 0.}, 849.603}, {{2007, 10, 10, 0, 0, 0.}, 
          855.445}, {{2008, 1, 2, 0, 0, 0.}, 847.977}, {{
          2008, 4, 9, 0, 0, 0.}, 855.413}, {{2008, 7, 2, 0, 0, 0.}, 
          864.278}, {{2008, 10, 8, 0, 0, 0.}, 1016.657}, {{
          2009, 1, 14, 0, 0, 0.}, 1772.029}, {{2009, 4, 8, 0, 0, 0.}, 
          1752.626}, {{2009, 7, 1, 0, 0, 0.}, 1639.508}, {{
          2009, 10, 7, 0, 0, 0.}, 1883.673}, {{2010, 1, 13, 0, 0, 0.}, 
          1971.373}, {{2010, 4, 7, 0, 0, 0.}, 2076.166}, {{
          2010, 7, 14, 0, 0, 0.}, 2027.847}, {{2010, 10, 6, 0, 0, 0.}, 
          1972.212}, {{2011, 1, 12, 0, 0, 0.}, 2034.799}, {{
          2011, 4, 6, 0, 0, 0.}, 2490.388}, {{2011, 7, 13, 0, 0, 0.}, 
          2725.147}, {{2011, 10, 5, 0, 0, 0.}, 2656.63}, {{
          2012, 1, 11, 0, 0, 0.}, 2659.712}, {{2012, 4, 4, 0, 0, 0.}, 
          2658.503}, {{2012, 7, 11, 0, 0, 0.}, 2650.904}, {{
          2012, 10, 3, 0, 0, 0.}, 2589.432}, {{2013, 1, 9, 0, 0, 0.}, 
          2705.366}}, $CellContext`velocitymb = CompressedData["
1:eJwNkH1Qk3UAx0fKiIDSS9kAeZkIhK49z2/P8/gK8jVNCE5kC4kZJC4JcCpM
GVq8VEKgyJl6wFk3A04chYDgAU0k5EVKXhQ8haUZAceSiSZCOA7h6vnje5+7
zz+fu69EnayMtxEIBKn8Hv6d1JJzgcPkf7ebY/QcprvO7PqogUPDt8cCVg5x
MCt1gYWDHESTJQa7XznoonuOfJLHQdinmW7cx+G1wlaTcA0H2WNLp2aKRYZM
c6qsicVAvdcBk5TFX5lh/c1qFi1hv21wTmBRvHdZz+kkFl7tzqbI7SxuxYU4
GlNYzDj1C122sdB1J3+Rf5JF9ayvSFfNokia3imxsPgnN8gaMMfiQH0yVS7i
kKKMuD/ny+Fox6OWJU4c5pXZpRtaWdxpjArVrmZx1l93/HoHg86hp4WPixjY
MnXaR5kM7qZODL6RxsBnelHLzzsYOOpHD1mlDCZ2C2o/tWcwXNHt6quXI8j1
g0vqSDkqpN6G9/zlUDk8L/EzEcg3zud+V0Rwa42NKf8bAunZnY4zsQQ36kyU
+xaCEJH05YiCwG3YElgaRXBtMVex4EFQLey320gRDHfv0XuvI5j8eLkRYQQ/
GU39J7IJxkL9Zi5nElwp9jM2nCCwrdrqE8r7LSvK8+34To4muzWjmO95P29c
f5Jgs+vaptrPCBZK/zi/O5ogJs7mdUsSgVL/w6JEFUFa3rXN+mQCmyD5ORXf
7/uqtDdrFcHbSeUGykwjehtdcH6Ago20bLhrKcElpWLGx5NgViLO6ZEQONUO
lep5dufPTxQs0EhZfjAtvY1GRkF6ssqXxlN9XoWModHYHJBY1EDBKTH9WVQG
hTjBW+s+JBRm7dsn16ZRGB8N3nvmTxnenZKZgmMo5GXF/16iorDr3ohn4BCF
6C9vJMSYKWgnKLmxjcJ+RW6bZoyCS3i/5ysljYP2idbeQBpf16zefy+BRvih
h33ywzTM7dYnS2poxGZFFTd8T2NTwipL3o80br7/zsXKBzTUbr8ER07zXLp4
4ZQT/+PnXSUdvvy/LmVvekoJXpw2dlTtIPjXWFevVBJomZRjZt4PpjqIRi9I
8cBoO75+kxdUR6bY27FeEF69Gu5cIMG4RKZVPPNARPz1xsROdxjmq2YvV67A
6M370zVX3HFnrmzk+JgHXolbVppfuqNeWKm6OCBGc7VQE/LEGf6KrerIuyLs
m3A1L/MSI0K6M8wQIUb+iz29jjVizGkd/I7GukBdY3VrOizG/3NNkMY=
        
        "], $CellContext`gdpDates = {{1984, 4, 1, 0, 0, 0.}, {
         1984, 7, 1, 0, 0, 0.}, {1984, 10, 1, 0, 0, 0.}, {
         1985, 1, 1, 0, 0, 0.}, {1985, 4, 1, 0, 0, 0.}, {
         1985, 7, 1, 0, 0, 0.}, {1985, 10, 1, 0, 0, 0.}, {
         1986, 1, 1, 0, 0, 0.}, {1986, 4, 1, 0, 0, 0.}, {
         1986, 7, 1, 0, 0, 0.}, {1986, 10, 1, 0, 0, 0.}, {
         1987, 1, 1, 0, 0, 0.}, {1987, 4, 1, 0, 0, 0.}, {
         1987, 7, 1, 0, 0, 0.}, {1987, 10, 1, 0, 0, 0.}, {
         1988, 1, 1, 0, 0, 0.}, {1988, 4, 1, 0, 0, 0.}, {
         1988, 7, 1, 0, 0, 0.}, {1988, 10, 1, 0, 0, 0.}, {
         1989, 1, 1, 0, 0, 0.}, {1989, 4, 1, 0, 0, 0.}, {
         1989, 7, 1, 0, 0, 0.}, {1989, 10, 1, 0, 0, 0.}, {
         1990, 1, 1, 0, 0, 0.}, {1990, 4, 1, 0, 0, 0.}, {
         1990, 7, 1, 0, 0, 0.}, {1990, 10, 1, 0, 0, 0.}, {
         1991, 1, 1, 0, 0, 0.}, {1991, 4, 1, 0, 0, 0.}, {
         1991, 7, 1, 0, 0, 0.}, {1991, 10, 1, 0, 0, 0.}, {
         1992, 1, 1, 0, 0, 0.}, {1992, 4, 1, 0, 0, 0.}, {
         1992, 7, 1, 0, 0, 0.}, {1992, 10, 1, 0, 0, 0.}, {
         1993, 1, 1, 0, 0, 0.}, {1993, 4, 1, 0, 0, 0.}, {
         1993, 7, 1, 0, 0, 0.}, {1993, 10, 1, 0, 0, 0.}, {
         1994, 1, 1, 0, 0, 0.}, {1994, 4, 1, 0, 0, 0.}, {
         1994, 7, 1, 0, 0, 0.}, {1994, 10, 1, 0, 0, 0.}, {
         1995, 1, 1, 0, 0, 0.}, {1995, 4, 1, 0, 0, 0.}, {
         1995, 7, 1, 0, 0, 0.}, {1995, 10, 1, 0, 0, 0.}, {
         1996, 1, 1, 0, 0, 0.}, {1996, 4, 1, 0, 0, 0.}, {
         1996, 7, 1, 0, 0, 0.}, {1996, 10, 1, 0, 0, 0.}, {
         1997, 1, 1, 0, 0, 0.}, {1997, 4, 1, 0, 0, 0.}, {
         1997, 7, 1, 0, 0, 0.}, {1997, 10, 1, 0, 0, 0.}, {
         1998, 1, 1, 0, 0, 0.}, {1998, 4, 1, 0, 0, 0.}, {
         1998, 7, 1, 0, 0, 0.}, {1998, 10, 1, 0, 0, 0.}, {
         1999, 1, 1, 0, 0, 0.}, {1999, 4, 1, 0, 0, 0.}, {
         1999, 7, 1, 0, 0, 0.}, {1999, 10, 1, 0, 0, 0.}, {
         2000, 1, 1, 0, 0, 0.}, {2000, 4, 1, 0, 0, 0.}, {
         2000, 7, 1, 0, 0, 0.}, {2000, 10, 1, 0, 0, 0.}, {
         2001, 1, 1, 0, 0, 0.}, {2001, 4, 1, 0, 0, 0.}, {
         2001, 7, 1, 0, 0, 0.}, {2001, 10, 1, 0, 0, 0.}, {
         2002, 1, 1, 0, 0, 0.}, {2002, 4, 1, 0, 0, 0.}, {
         2002, 7, 1, 0, 0, 0.}, {2002, 10, 1, 0, 0, 0.}, {
         2003, 1, 1, 0, 0, 0.}, {2003, 4, 1, 0, 0, 0.}, {
         2003, 7, 1, 0, 0, 0.}, {2003, 10, 1, 0, 0, 0.}, {
         2004, 1, 1, 0, 0, 0.}, {2004, 4, 1, 0, 0, 0.}, {
         2004, 7, 1, 0, 0, 0.}, {2004, 10, 1, 0, 0, 0.}, {
         2005, 1, 1, 0, 0, 0.}, {2005, 4, 1, 0, 0, 0.}, {
         2005, 7, 1, 0, 0, 0.}, {2005, 10, 1, 0, 0, 0.}, {
         2006, 1, 1, 0, 0, 0.}, {2006, 4, 1, 0, 0, 0.}, {
         2006, 7, 1, 0, 0, 0.}, {2006, 10, 1, 0, 0, 0.}, {
         2007, 1, 1, 0, 0, 0.}, {2007, 4, 1, 0, 0, 0.}, {
         2007, 7, 1, 0, 0, 0.}, {2007, 10, 1, 0, 0, 0.}, {
         2008, 1, 1, 0, 0, 0.}, {2008, 4, 1, 0, 0, 0.}, {
         2008, 7, 1, 0, 0, 0.}, {2008, 10, 1, 0, 0, 0.}, {
         2009, 1, 1, 0, 0, 0.}, {2009, 4, 1, 0, 0, 0.}, {
         2009, 7, 1, 0, 0, 0.}, {2009, 10, 1, 0, 0, 0.}, {
         2010, 1, 1, 0, 0, 0.}, {2010, 4, 1, 0, 0, 0.}, {
         2010, 7, 1, 0, 0, 0.}, {2010, 10, 1, 0, 0, 0.}, {
         2011, 1, 1, 0, 0, 0.}, {2011, 4, 1, 0, 0, 0.}, {
         2011, 7, 1, 0, 0, 0.}, {2011, 10, 1, 0, 0, 0.}, {
         2012, 1, 1, 0, 0, 0.}, {2012, 4, 1, 0, 0, 0.}, {
         2012, 7, 1, 0, 0, 0.}, {2012, 10, 1, 0, 0, 0.}, {
         2013, 1, 1, 0, 0, 0.}}}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellGroupingRules->"InputGrouping"],

Cell[TextData[StyleBox["The foregoing comments represent the general \
investment analysis and economic views of the advisor, and are provided \
solely for the purpose of information, instruction, and discourse.",
 FontSize->14,
 FontSlant->"Italic"]], "Text",
 CellFrame->{{0, 0}, {0, 0.5}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{934, 780},
WindowTitle->"Liquidity Trap",
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->False,
Deployed->True,
TaggingRules->{
 "ReportCreationDate" -> "Mathematica report created on 20 September 2013", 
  "Highlight" -> True},
CellContext->Notebook,
ShowCellTags->True,
TrackCellChangeTimes->False,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell["Style Environment Names", "Section"], 
      Cell[
       StyleData[All, "Working"], $CellContext`GhostCellInEmptyNotebook -> 
       False, $CellContext`CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"]], 
      Cell[
       StyleData[All, "Presentation"], MenuSortingValue -> None], 
      Cell[
       StyleData[All, "Condensed"], MenuSortingValue -> None], 
      Cell[
       StyleData[All, "SlideShow"], MenuSortingValue -> None], 
      Cell[
       StyleData[All, "Printout"], Magnification -> 0.72], 
      Cell[
       StyleData[All, "PrintoutGray"], MenuSortingValue -> None]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Title and Section Cells", "Section"], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], ShowCellBracket -> Automatic, 
          CellMargins -> {{0, 0}, {30, 0}}, 
          CellBracketOptions -> {
           "Margins" -> {0, 0}, "OverlapContent" -> True}, 
          CellGroupingRules -> {"TitleGrouping", 0}, 
          CellFrameMargins -> {{60, 20}, {25, 35}}, FontFamily -> "Gill Sans",
           FontSize -> 56, FontColor -> GrayLevel[1], Background -> 
          RGBColor[0.28, 0.5, 0.74]], 
         Cell[
          StyleData["Title", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{2, 0}, {0, 20}}, LineSpacing -> {1, 18}, FontSize -> 
          15]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subtitle"], ShowCellBracket -> False, 
          CellMargins -> {{60, 0}, {0, 5}}, 
          CellBracketOptions -> {"Margins" -> {0, 0}}, 
          CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> False,
           DefaultNewInlineCellStyle -> "None", 
          InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, TextAlignment -> Left, LanguageCategory -> 
          "NaturalLanguage", CounterIncrements -> "Subtitle", 
          CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
            "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Helvetica", 
          FontSize -> 20, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> RGBColor[0.4, 0.4, 0.4], Background -> None], 
         Cell[
          StyleData["Subtitle", "Presentation", StyleDefinitions -> None], 
          CellMargins -> {{58, 0}, {0, 5}}, FontSize -> 20], 
         Cell[
          StyleData[
          "Subtitle", "SlideShow", StyleDefinitions -> 
           StyleData["Subtitle", "Presentation"]]], 
         Cell[
          StyleData["Subtitle", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{2, 0}, {0, 5}}, FontSize -> 14, Background -> 
          GrayLevel[1]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubtitle", StyleDefinitions -> StyleData["Subtitle"]],
           FontSize -> 3 + Inherited], 
         Cell[
          StyleData["Subsubtitle", "Presentation"], FontSize -> 
          3 + Inherited], 
         Cell[
          StyleData[
          "Subsubtitle", "SlideShow", StyleDefinitions -> 
           StyleData["Subsubtitle", "Presentation"]]], 
         Cell[
          StyleData["Subsubtitle", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0.2, 0}}, 
          ShowGroupOpener -> False, CellMargins -> {{60, 50}, {20, 25}}, 
          FontSize -> 36, FontWeight -> "Plain", FontColor -> 
          RGBColor[0.28, 0.5, 0.74]], 
         Cell[
          StyleData["Section", "Presentation"], 
          CellFrame -> {{0, 0}, {0.2, 0}}, 
          CellMargins -> {{58, 50}, {10, 35}}], 
         Cell[
          StyleData[
          "Section", "SlideShow", StyleDefinitions -> 
           StyleData["Section", "Presentation"]], 
          CellMargins -> {{58, 50}, {10, 35}}], 
         Cell[
          StyleData["Section", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{2, 0}, {7, 22}}, FontSize -> 14]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellDingbat -> None, ShowGroupOpener -> 
          False, CellMargins -> {{60, Inherited}, {0, 12}}, 
          CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
          False, DefaultNewInlineCellStyle -> "None", 
          InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, LanguageCategory -> "NaturalLanguage", 
          CounterIncrements -> "Subsection", 
          CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
          "Helvetica", FontSize -> 24, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> RGBColor[0.4, 0.4, 0.4]], 
         Cell[
          StyleData["Subsection", "Presentation"], ShowGroupOpener -> True, 
          CellMargins -> {{60, 50}, {6, 15}}, LineSpacing -> {1, 0}, 
          FontFamily -> "Helvetica", $CellContext`WholeCellGroupOpener -> 
          True], 
         Cell[
          StyleData["Subsection", "SlideShow"], ShowGroupOpener -> True, 
          CellMargins -> {{60, 50}, {8, 12}}, LineSpacing -> {1, 0}, 
          FontFamily -> "Helvetica", $CellContext`WholeCellGroupOpener -> 
          True], 
         Cell[
          StyleData["Subsection", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{2, 0}, {2, 22}}, FontSize -> 12]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], CellDingbat -> None, ShowGroupOpener -> 
          False, CellMargins -> {{60, Inherited}, {0, 12}}, 
          CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
          False, DefaultNewInlineCellStyle -> "None", 
          InputAutoReplacements -> {"TeX" -> StyleBox[
              RowBox[{"T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
              RowBox[{"L", 
                StyleBox[
                 AdjustmentBox[
                 "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                AdjustmentBox[
                "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                 BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
            "Mma" -> "Mathematica", "MMA" -> "Mathematica", "gridMathematica" -> 
            FormBox[
              RowBox[{"grid", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            "webMathematica" -> FormBox[
              RowBox[{"web", 
                AdjustmentBox[
                 StyleBox["Mathematica", FontSlant -> "Italic"], 
                 BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
            Inherited}, LanguageCategory -> "NaturalLanguage", 
          CounterIncrements -> "Subsubsection", FontFamily -> "Helvetica", 
          FontSize -> 24, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> RGBColor[0.4, 0.4, 0.4]], 
         Cell[
          StyleData["Subsubsection", "Presentation"], ShowGroupOpener -> True,
           CellMargins -> {{60, 50}, {6, 20}}, 
          LineSpacing -> {1, 0}, $CellContext`WholeCellGroupOpener -> True], 
         Cell[
          StyleData[
          "Subsubsection", "SlideShow", StyleDefinitions -> 
           StyleData["Subsubsection", "Presentation"]]], 
         Cell[
          StyleData["Subsubsection", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{2, 0}, {2, 22}}, FontSize -> 11]}, Closed]]}, 
     Open]]}, WindowSize -> {740, 867}, 
  WindowMargins -> {{20, Automatic}, {Automatic, 44}}, FrontEndVersion -> 
  "9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, 2013)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1513, 36, 31, 0, 155, "Title"],
Cell[1547, 38, 551, 8, 87, "Text"],
Cell[CellGroupData[{
Cell[2123, 50, 62, 0, 92, "Section"],
Cell[2188, 52, 375, 6, 68, "Text"],
Cell[2566, 60, 362, 6, 68, "Text"],
Cell[2931, 68, 12983, 256, 411, "Output",
 CellGroupingRules->"InputGrouping"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15951, 329, 60, 0, 92, "Section"],
Cell[16014, 331, 251, 4, 49, "Text"],
Cell[16268, 337, 135216, 3225, 595, "Output",
 CellGroupingRules->"InputGrouping"]
}, Open  ]],
Cell[CellGroupData[{
Cell[151521, 3567, 44, 0, 92, "Section"],
Cell[151568, 3569, 512, 8, 87, "Text"],
Cell[152083, 3579, 30407, 532, 562, "Output",
 CellGroupingRules->"InputGrouping"],
Cell[182493, 4113, 292, 5, 57, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature BXOn34D#be6TfUzGzx3uovXc *)
